%define build_test 0
%{?_with_test: %{expand: %%global build_test 1}}
%{?_without_test: %{expand: %%global build_test 0}}

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

# hardcode build_arch for imagemagick, otherwise it will run in to SIGFAULT
%define build_arch %(echo %{_target_cpu} | sed -e 's/_/-/')

# V E R S I O N   P A R T S

# their "official" version
%define rversion 7.1.1

# their "minor" version
%define minor_rev 47

# some other funny version
# (aw) from the docs: Versions with Q8 in the name are 8 bits-per-pixel
# component (e.g. 8-bit red, 8-bit green, etc.), whereas, Q16 in the
# filename are 16 bits-per-pixel component. A Q16 version permits you
# to read or write 16-bit images without losing precision but requires
# twice as much resources as the Q8 version.
%define qlev Q16HDRI

# the full file version
%define dversion %{rversion}-%{minor_rev}

%define major 10
%define cppmajor 5

%define libname   %mklibname magick-7 %{qlev} %{major}
%define libcpp    %mklibname magick++-7 %{qlev} %{cppmajor}
%define develname %mklibname magick -d

Summary:        An X application for displaying and manipulating images
Name:           imagemagick
Version:        %{rversion}.%{minor_rev}
Release:        %mkrel 1
License:        ASL 2.0
Group:          Graphics/Editors and Converters
URL:            https://www.imagemagick.org/
Source0:        https://imagemagick.org/archive/ImageMagick-%{dversion}.tar.xz
Source1:        https://imagemagick.org/archive/ImageMagick-%{dversion}.tar.xz.asc
Source2:        ImageMagick.pdf.bz2
# re-scaled from ftp://ftp.imagemagick.org/pub/ImageMagick/images/magick-icon.png
Source10:       magick-icon_16x16.png
Source11:       magick-icon_32x32.png
Source12:       magick-icon_48x48.png
Source13:       magick-icon_64x64.png
Patch0:         ImageMagick-7.0.7-docdir.patch
Patch2:         ImageMagick-7.1.0-force-so.patch
Patch7:         ImageMagick-7.0.7-urw.patch
Patch17:        ImageMagick-7.0.10-fpx.patch
Patch19:        ImageMagick-7.0.7-libpath.patch
Patch20:        ImageMagick-7.0.7-fix-montageimages-test.patch
Patch21:        ImageMagick-LPRDelegate.patch

Provides:       ImageMagick = %{version}-%{release}

BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  bzip2-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 2.1.7
BuildRequires:  chrpath
BuildRequires:  graphviz-devel >= 2.9.0
BuildRequires:  libjbig-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(lqr-1)
BuildRequires:  libltdl-devel
BuildRequires:  perl-devel
BuildRequires:  pkgconfig(libraw_r)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwmf)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(OpenEXR) >= 1.0.6
BuildRequires:  pkgconfig(OpenCL)
BuildRequires:  pkgconfig(raqm)
%if !%bootstrap
BuildRequires:  pkgconfig(ddjvuapi)
%endif
BuildRequires:  ghostscript
BuildRequires:  ghostscript-devel
BuildRequires:  subversion
%if "%distro_section" == "tainted"
BuildRequires:  pkgconfig(libde265)
BuildRequires:  pkgconfig(libheif)
Recommends:     libde265
Recommends:     libheif
%endif
BuildRequires:  pkgconfig(libjxl)
BuildRequires:  %{_lib}qoi-devel

Requires:       potrace

%description
ImageMagick is a powerful image display, conversion and manipulation tool. It
runs in an X session. With this tool, you can view, edit and display a variety
of image formats.

ImageMagick can make use of the following delegate programs, available as
packages in %{_vendor}: curl enscript ffmpeg ghostscript ghostscript-X gimp
gnuplot graphviz html2ps mplayer ncompress netpbm sane-backends texlive-texmf
transfig ufraw xdg-utils zip autotrace povray

The tainted package supports converting heif/heic image formats.

%package        desktop
Summary:        ImageMagick menus
Group:          Graphics/Editors and Converters
Requires:       xterm

%description    desktop
This package contains the menu and .desktop entries to run the "display"
command from the menu.

%package -n     %{libname}
Summary:        ImageMagick libraries
Group:          System/Libraries
Provides:       %{_lib}magick = %{version}

%description -n %{libname}
This package contains the libraries needed to run programs dynamically linked
with ImageMagick libraries.

%package -n     %{libcpp}
Summary:        ImageMagick libraries
Group:          System/Libraries

%description -n %{libcpp}
This package contains the libraries needed to run programs dynamically linked
with ImageMagick libraries.

%package -n     %{develname}
Summary:        Static libraries and header files for ImageMagick app development
Group:          Development/C
Requires:       %{libname} = %{version}
Requires:       %{libcpp} = %{version}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       ImageMagick-devel = %{version}-%{release}
Provides:       libmagick-devel = %{version}-%{release}
Provides:       libMagick-devel = %{version}-%{release}

%description -n %{develname}
If you want to create applications that will use ImageMagick code or APIs,
you'll need to install these packages as well as ImageMagick. These additional
packages aren't necessary if you simply want to use ImageMagick, however.

ImageMagick-devel is an addition to ImageMagick which includes static libraries
and header files necessary to develop applications.

%package -n     perl-Image-Magick
Summary:        Libraries and modules for access to ImageMagick from perl
Group:          Development/Perl
Requires:       %{name} = %{version}
Provides:       perl-Magick = %{version}-%{release}

%description -n perl-Image-Magick
This is the ImageMagick perl support package. It includes perl modules and
support files for access to ImageMagick library from perl.

%package        doc
Summary:        %{name} Documentation
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains HTML/PDF documentation of %{name}.

%prep

%setup -q -n ImageMagick-%{rversion}-%{minor_rev}
%autopatch -p1

bzcat %{SOURCE2} > ImageMagick.pdf
install -m 644 %{SOURCE10} %{SOURCE11} %{SOURCE12} %{SOURCE13} .

%build
#autoreconf -fi

#gw the format-string patch is incomplete:
%define Werror_cflags %nil
%define _disable_ld_no_undefined 1
export CFLAGS="%{optflags} -fno-strict-aliasing -fPIC -DIMPNG_SETJMP_IS_THREAD_SAFE"
export CXXFLAGS="%{optflags} -fno-strict-aliasing -fPIC"

# don't use icecream
export PATH=/bin:/usr/bin

%configure \
    --docdir=%{_defaultdocdir}/imagemagick \
    --with-gcc-arch=generic \
    --with-pic \
    --enable-shared --disable-static \
    --enable-fast-install \
    --with-threads \
    --with-magick_plus_plus \
    --with-gslib \
    --with-wmf \
    --with-lcms \
    --with-rsvg \
    --with-xml \
    --without-dps \
    --without-windows-font-dir \
    --with-modules \
    --with-perl \
    --with-perl-options="INSTALLDIRS=vendor CC='%{__cc} -L$PWD/magick/.libs' LDDLFLAGS='-shared -L$PWD/magick/.libs' INSTALLVENDORMAN3DIR=%{_mandir}/man3 INSTALLVENDORARCH=%{perl_vendorarch}" \
    --with-openjp2 \
    --with-gvc \
    --with-lqr \
    --with-raw \
    --with-gvc \
    --with-jxl \
    --with-raqm \
    --with-jbig \
    --with-fftw

# Disable rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build

%if %{build_test}
%check
# these tests require X
if [ -f PerlMagick/t/x11/read.t ]; then
        mv PerlMagick/t/x11/read.t PerlMagick/t/x11/read.t.disabled
fi
if [ -f PerlMagick/t/x11/write.t ]; then
        mv PerlMagick/t/x11/write.t PerlMagick/t/x11/write.t.disabled
fi
#dlname=`grep "^dlname" Magick++/lib/.libs/libMagick++.la | cut -d\' -f2`
#LD_PRELOAD="$PWD/Magick++/lib/.libs/$dlname" VERBOSE="1" make check
make check
%endif

%install
# TODO: temporarily disable "empty" RPATHs checking, until finding a better solution
export QA_RPATHS=$((0x0010))

# (Abel) set LD_RUN_PATH to null, to avoid adding rpath to perlmagick module
%make_install LD_RUN_PATH="" pkgdocdir=/installed_docs

# fix docs inclusion (fix an unknown new rpm bug)
rm -rf installed_docs; mv %{buildroot}/installed_docs .

# Remove unpackaged files
find %{buildroot} -name '*.la' -delete

# create compatible symlinks
ln -s libMagick++-7.%{qlev}.so %{buildroot}%{_libdir}/libMagick++.so
ln -s libMagickCore-7.%{qlev}.so %{buildroot}%{_libdir}/libMagickCore.so
ln -s libMagickWand-7.%{qlev}.so %{buildroot}%{_libdir}/libMagickWand.so

%multiarch_binaries %{buildroot}%{_bindir}/Magick++-config
%multiarch_binaries %{buildroot}%{_bindir}/MagickCore-config
%multiarch_binaries %{buildroot}%{_bindir}/MagickWand-config
%multiarch_includes %{buildroot}%{_includedir}/ImageMagick-7/MagickCore/magick-baseconfig.h

# fix invalid rights
chmod 755 \
        %{buildroot}%{perl_vendorarch}/auto/Image/Magick/%{qlev}/%{qlev}.so

find %{buildroot} -name "perllocal.pod" -delete

# icons
install -m 755 -d %{buildroot}%{_liconsdir} \
           %{buildroot}%{_iconsdir} \
           %{buildroot}%{_iconsdir}/hicolor/64x64/apps \
           %{buildroot}%{_miconsdir}
install -m 644 magick-icon_16x16.png %{buildroot}%{_miconsdir}/%{name}.png
install -m 644 magick-icon_32x32.png %{buildroot}%{_iconsdir}/%{name}.png
install -m 644 magick-icon_48x48.png %{buildroot}%{_liconsdir}/%{name}.png
install -m 644 magick-icon_64x64.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png


install -m 755 -d %{buildroot}%{_datadir}/applications/
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=ImageMagick
Comment=Views Graphics files
Exec=%{_bindir}/xterm -geometry 40x15 -title ImageMagick +sb -iconic -e %{_bindir}/display
Icon=%{name}
Terminal=false
Type=Application
Categories=Graphics;Viewer;
EOF

%files
%doc README.md
%{_sysconfdir}/ImageMagick-7
%{_bindir}/animate
%{_bindir}/compare
%{_bindir}/composite
%{_bindir}/convert
%{_bindir}/conjure
%{_bindir}/display
%{_bindir}/identify
%{_bindir}/import
%{_bindir}/magick
%{_bindir}/magick-script
%{_bindir}/mogrify
%{_bindir}/montage
%{_bindir}/stream
%{_libdir}/ImageMagick-%{rversion}
%{_datadir}/ImageMagick-7
%{_mandir}/man1/*
%exclude %{_mandir}/man1/*-config.*

%files desktop
%{_datadir}/applications/*.desktop
%{_iconsdir}/%{name}.png
%{_liconsdir}/%{name}.png
%{_miconsdir}/%{name}.png
%{_iconsdir}/hicolor/64x64/apps/%{name}.png

%files -n %{libname}
%{_libdir}/libMagickCore-7.%{qlev}.so.%{major}{,.*}
%{_libdir}/libMagickWand-7.%{qlev}.so.%{major}{,.*}

%files -n %{libcpp}
%{_libdir}/libMagick++-7.%{qlev}.so.%{cppmajor}{,.*}

%files -n %{develname}
%{_includedir}/ImageMagick-7
%multiarch %{multiarch_bindir}/Magick++-config
%multiarch %{multiarch_bindir}/MagickCore-config
%multiarch %{multiarch_bindir}/MagickWand-config
%multiarch %dir %{multiarch_includedir}/ImageMagick-7
%multiarch %dir %{multiarch_includedir}/ImageMagick-7/MagickCore
%multiarch %{multiarch_includedir}/ImageMagick-7/MagickCore/magick-baseconfig.h
%{_bindir}/Magick++-config
%{_bindir}/MagickCore-config
%{_bindir}/MagickWand-config
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man1/*-config.*

%files -n perl-Image-Magick
%{perl_vendorarch}/Image
%{perl_vendorarch}/auto/Image
#{perl_vendorarch}/perllocal.pod
%{_mandir}/man3*/*::*.3pm*

%files doc
%doc ImageMagick.pdf LICENSE NOTICE
%doc installed_docs/*
%{_docdir}/ImageMagick-7/


%changelog
* Tue Apr 29 2025 ns80 <ns80> 7.1.1.47-1.mga10
+ Revision: 2179842
- new version 7.1.1.47 for CVE-2025-43965 and CVE-2025-46393 (mga#34225)

* Sun Mar 16 2025 wally <wally> 7.1.1.41-3.mga10
+ Revision: 2164870
- rebuild for libxml2 2.13.6

* Mon Dec 30 2024 daviddavid <daviddavid> 7.1.1.41-2.mga10
+ Revision: 2131671
- rebuild for new libraw 0.21.3

* Sun Nov 17 2024 kekepower <kekepower> 7.1.1.41-1.mga10.tainted
+ Revision: 2116814
- Update to version 7.1.1.41

* Thu Nov 14 2024 kekepower <kekepower> 7.1.1.40-1.mga10.tainted
+ Revision: 2115156
- Update to version 7.1.1.40

* Sun Oct 06 2024 kekepower <kekepower> 7.1.1.39-1.mga10.tainted
+ Revision: 2103846
- Update to version 7.1.1.39

* Mon Sep 02 2024 kekepower <kekepower> 7.1.1.38-1.mga10.tainted
+ Revision: 2092584
- Update to version 7.1.1.38

* Sun Aug 25 2024 kekepower <kekepower> 7.1.1.37-1.mga10.tainted
+ Revision: 2091384
- Update to version 7.1.1.37

* Fri Aug 23 2024 tv <tv> 7.1.1.35-3.mga10
+ Revision: 2089677
- Rebuild for perl-5.40

* Tue Jul 16 2024 kekepower <kekepower> 7.1.1.35-2.mga10.tainted
+ Revision: 2081777
- Update to version 7.1.1.35

* Fri Jul 05 2024 daviddavid <daviddavid> 7.1.1.34-2.mga10.tainted
+ Revision: 2079925
- rebuild for new libjxl 0.10.3

* Sun Jun 23 2024 kekepower <kekepower> 7.1.1.34-1.mga10.tainted
+ Revision: 2076311
- Update to version 7.1.1.34

* Sun May 26 2024 kekepower <kekepower> 7.1.1.33-1.mga10.tainted
+ Revision: 2067691
- Update to version 7.1.1.33

* Mon May 06 2024 kekepower <kekepower> 7.1.1.32-1.mga10
+ Revision: 2062585
- Update to version 7.1.1.32

* Tue Apr 23 2024 kekepower <kekepower> 7.1.1.31-1.mga10.tainted
+ Revision: 2060625
- Update to version 7.1.1.31

* Wed Apr 10 2024 kekepower <kekepower> 7.1.1.30-1.mga10.tainted
+ Revision: 2056435
- Fix configure options regarding PerlMagick
- Update to version 7.1.1.30

* Sun Feb 25 2024 kekepower <kekepower> 7.1.1.29-1.mga10.tainted
+ Revision: 2044265
- Update to version 7.1.1.29

* Sun Feb 11 2024 kekepower <kekepower> 7.1.1.28-1.mga10.tainted
+ Revision: 2040353
- Update to version 7.1.1.28

* Thu Jan 25 2024 kekepower <kekepower> 7.1.1.27-1.mga10.tainted
+ Revision: 2034180
- Update to version 7.1.1.27

* Tue Jan 09 2024 kekepower <kekepower> 7.1.1.26-1.mga10.tainted
+ Revision: 2029073
- Update to version 7.1.1.26
- Update to version 7.1.1.24

* Mon Dec 11 2023 kekepower <kekepower> 7.1.1.23-1.mga10
+ Revision: 2017150
- Update to version 7.1.1.23

* Tue Dec 05 2023 kekepower <kekepower> 7.1.1.22-1.mga10.tainted
+ Revision: 2013354
- Update to version 7.1.1.22

* Sat Dec 02 2023 tv <tv> 7.1.1.21-8.mga10
+ Revision: 2012642
- Rebuild for perl-5.38

* Thu Nov 23 2023 wally <wally> 7.1.1.21-7.mga10.tainted
+ Revision: 2009339
- add one more patche to fix /usr/bin/convert error on 32 bit arches

* Thu Nov 23 2023 wally <wally> 7.1.1.21-6.mga10.tainted
+ Revision: 2009335
- add upstream patch to fix 'time limit exceeded' errors with 32 bit /usr/bin/convert

* Fri Nov 10 2023 kekepower <kekepower> 7.1.1.21-5.mga10
+ Revision: 2005659
- Rebuild to see if it fixes the i586 error in convert
+ daviddavid <daviddavid>
- enable libzip and raqm support

* Tue Nov 07 2023 daviddavid <daviddavid> 7.1.1.21-3.mga10.tainted
+ Revision: 2005041
- rebuild for new libjxl 0.8.2

* Sat Oct 21 2023 kekepower <kekepower> 7.1.1.21-2.mga10.tainted
+ Revision: 2000044
- Update to version 7.1.1.21

* Sun Oct 15 2023 kekepower <kekepower> 7.1.1.20-2.mga10.tainted
+ Revision: 1996867
- Rebuild for dav1d 1.3.0

* Mon Oct 09 2023 kekepower <kekepower> 7.1.1.20-1.mga10.tainted
+ Revision: 1993744
- Update to version 7.1.1.20

* Sun Oct 01 2023 kekepower <kekepower> 7.1.1.19-1.mga10.tainted
+ Revision: 1992681
- Update to version 7.1.1.19

* Sun Sep 24 2023 kekepower <kekepower> 7.1.1.18-1.mga10.tainted
+ Revision: 1989835
- Update to version 7.1.1.18

* Wed Sep 20 2023 kekepower <kekepower> 7.1.1.17-1.mga10.tainted
+ Revision: 1988443
- Update to version 7.1.1.17

* Mon Sep 18 2023 kekepower <kekepower> 7.1.1.16-2.mga10.tainted
+ Revision: 1987828
- Update to version 7.1.1.16
+ wally <wally>
- add quotes to LPR delegate command

* Sun Sep 10 2023 wally <wally> 7.1.1.15-2.mga10
+ Revision: 1985873
- add patch to fix LPR delegate (mga#32256)

* Mon Aug 28 2023 kekepower <kekepower> 7.1.1.15-1.mga10.tainted
+ Revision: 1980453
- Update to version 7.1.1.15

* Fri Jun 16 2023 kekepower <kekepower> 7.1.1.11-2.mga9.tainted
+ Revision: 1962198
- Enable qoi - The Quite OK Image Format

* Wed May 31 2023 kekepower <kekepower> 7.1.1.11-1.mga9.tainted
+ Revision: 1960184
- Update to version 7.1.1.11

* Mon May 22 2023 kekepower <kekepower> 7.1.1.10-1.mga9.tainted
+ Revision: 1957682
- Update to version 7.1.1.10

* Fri Apr 21 2023 kekepower <kekepower> 7.1.1.7-1.mga9.tainted
+ Revision: 1953742
- Update to version 7.1.1.7

* Sat Apr 08 2023 kekepower <kekepower> 7.1.1.6-1.mga9.tainted
+ Revision: 1951768
- Update to version 7.1.1.6

* Wed Apr 05 2023 kekepower <kekepower> 7.1.0.62-3.mga9.tainted
+ Revision: 1951517
- Backport upstream fix for CVE-2023-1289 (mga#31761)

* Thu Feb 23 2023 daviddavid <daviddavid> 7.1.0.62-2.mga9.tainted
+ Revision: 1945128
- enable jpegxl support also on armv7 arch

* Mon Feb 13 2023 kekepower <kekepower> 7.1.0.62-1.mga9.tainted
+ Revision: 1941195
- Update to version 7.1.0.62

* Mon Feb 06 2023 kekepower <kekepower> 7.1.0.61-1.mga9.tainted
+ Revision: 1938690
- Update to version 7.1.0.61

* Mon Jan 30 2023 kekepower <kekepower> 7.1.0.60-1.mga9
+ Revision: 1936968
- Update to version 7.1.0.60

* Sun Jan 29 2023 kekepower <kekepower> 7.1.0.59-1.mga9.tainted
+ Revision: 1936741
- Update to version 7.1.0.59

* Sun Jan 22 2023 kekepower <kekepower> 7.1.0.58-1.mga9.tainted
+ Revision: 1934902
- Update to version 7.1.0.58

* Thu Jan 12 2023 kekepower <kekepower> 7.1.0.57-2.mga9.tainted
+ Revision: 1932675
- Enable FFTW

* Fri Dec 30 2022 kekepower <kekepower> 7.1.0.57-1.mga9.tainted
+ Revision: 1928317
- Update to version 7.1.0.57

* Thu Dec 29 2022 kekepower <kekepower> 7.1.0.56-1.mga9
+ Revision: 1927739
- Update to version 7.1.0.56

* Sun Dec 18 2022 kekepower <kekepower> 7.1.0.55-1.mga9.tainted
+ Revision: 1924871
- Update to version 7.1.0.55

* Mon Dec 12 2022 ns80 <ns80> 7.1.0.54-4.mga9
+ Revision: 1921045
- rebuild for new libtiff

* Sun Dec 11 2022 kekepower <kekepower> 7.1.0.54-3.mga9.tainted
+ Revision: 1920659
- Upstream patch to fix proper Exif profile handling in HEIC

* Sat Dec 10 2022 kekepower <kekepower> 7.1.0.54-2.mga9.tainted
+ Revision: 1920483
- Update to version 7.1.0.54

* Tue Dec 06 2022 kekepower <kekepower> 7.1.0.53-2.mga9.tainted
+ Revision: 1918596
- Add upstream patches to correct EXIF profile extraction from JXL images

* Sun Dec 04 2022 kekepower <kekepower> 7.1.0.53-1.mga9
+ Revision: 1917745
- Update to version 7.1.0.53

* Wed Nov 30 2022 ns80 <ns80> 7.1.0.52-3.mga9.tainted
+ Revision: 1913243
- rebuild for new jbigkit (mga#31189)

* Fri Nov 18 2022 kekepower <kekepower> 7.1.0.52-2.mga9
+ Revision: 1908668
- Build with jpeg-xl on supported arches

* Sun Nov 06 2022 kekepower <kekepower> 7.1.0.52-1.mga9.tainted
+ Revision: 1904047
- Update to version 7.1.0.52

* Sun Oct 16 2022 kekepower <kekepower> 7.1.0.51-1.mga9.tainted
+ Revision: 1897148
- Update to version 7.1.0.51

* Sun Oct 09 2022 kekepower <kekepower> 7.1.0.50-1.mga9.tainted
+ Revision: 1895645
- Update to version 7.1.0.50

* Thu Oct 06 2022 kekepower <kekepower> 7.1.0.49-2.mga9
+ Revision: 1895132
- Require potrace in order to convert to svg images

* Sun Sep 25 2022 kekepower <kekepower> 7.1.0.49-1.mga9.tainted
+ Revision: 1892182
- Update to version 7.1.0.49

* Sun Sep 11 2022 kekepower <kekepower> 7.1.0.48-1.mga9.tainted
+ Revision: 1887274
- Update to version 7.1.0.48

* Sun Aug 28 2022 kekepower <kekepower> 7.1.0.47-1.mga9.tainted
+ Revision: 1881493
- Update to version 7.1.0.47

* Sun Aug 21 2022 kekepower <kekepower> 7.1.0.46-1.mga9
+ Revision: 1878998
- Update to version 7.1.0.46

* Sat Aug 06 2022 kekepower <kekepower> 7.1.0.45-1.mga9.tainted
+ Revision: 1875693
- Update to version 7.1.0.45

* Mon Jul 25 2022 kekepower <kekepower> 7.1.0.44-1.mga9
+ Revision: 1871418
- Update to version 7.1.0.44

* Wed Jul 13 2022 kekepower <kekepower> 7.1.0.43-1.mga9
+ Revision: 1868725
- Update to version 7.1.0.43

* Sat Jul 09 2022 kekepower <kekepower> 7.1.0.42-1.mga9.tainted
+ Revision: 1868154
- Update to version 7.1.0.42

* Tue Jul 05 2022 kekepower <kekepower> 7.1.0.40-2.mga9.tainted
+ Revision: 1867717
- Update to version 7.1.0.40

* Wed Jun 22 2022 kekepower <kekepower> 7.1.0.39-2.mga9.tainted
+ Revision: 1865393
- Update to version 7.1.0.39

* Tue Jun 07 2022 umeabot <umeabot> 7.1.0.37-2.mga9.tainted
+ Revision: 1863168
- Rebuild for Perl 5.36

* Sun Jun 05 2022 kekepower <kekepower> 7.1.0.37-1.mga9
+ Revision: 1861342
- Update to version 7.1.0.37

* Mon May 16 2022 ghibo <ghibo> 7.1.0.34-4.mga9.tainted
+ Revision: 1858419
- Bring back --with-lcms instead of --with-lcms2
- Upload Patch100 and really use it
- Add patch (from deb) to fix a typo in html doc.

* Mon May 16 2022 ghibo <ghibo> 7.1.0.34-3.mga9
+ Revision: 1858392
- Add ghostscript-devel to BuildRequires
- Add pkgconfig(libraw_r) for supporting --with-raw

* Mon May 16 2022 ghibo <ghibo> 7.1.0.34-2.mga9
+ Revision: 1858381
- Disable bootstrap building.
- Use pkgconfig(ddjvuapi) instead of djvulibre-devel.

* Mon May 16 2022 ghibo <ghibo> 7.1.0.34-1.mga9.tainted
+ Revision: 1858375
- Update to release 7.1.0-34.
- Rediff Patch2.
- Remove unsupported --with-opencl configure option.
- Use --with-lcms2 instead of --with-lcms.

* Thu Mar 31 2022 umeabot <umeabot> 7.0.11.14-3.mga9.tainted
+ Revision: 1836518
- Mageia 9 Mass Rebuild

* Mon Dec 27 2021 ghibo <ghibo> 7.0.11.14-2.mga9.tainted
+ Revision: 1764304
- temporarily disable empty RPATHs checking, until finding a better solution
+ wally <wally>
- rebuild for openexr 3.1.3
+ akien <akien>
- Lib major is now 10
- Version 7.0.11-14

* Tue May 25 2021 tv <tv> 7.0.11.13-3.mga9.tainted
+ Revision: 1728103
- Rebuild for perl-5.34

* Mon May 24 2021 umeabot <umeabot> 7.0.11.13-2.mga9
+ Revision: 1727950
- Rebuild for perl 5.34

* Tue May 18 2021 kekepower <kekepower> 7.0.11.13-1.mga9.tainted
+ Revision: 1725460
- Update to version 7.0.11.13

* Sun May 16 2021 kekepower <kekepower> 7.0.11.12-1.mga9
+ Revision: 1724940
- Update to version 7.0.11.12

* Thu May 06 2021 kekepower <kekepower> 7.0.11.11-1.mga9.tainted
+ Revision: 1721883
- Update to version 7.0.11.11

* Fri Apr 30 2021 kekepower <kekepower> 7.0.11.10-1.mga9.tainted
+ Revision: 1720613
- Update to version 7.0.11.10

* Sun Apr 25 2021 kekepower <kekepower> 7.0.11.9-1.mga9
+ Revision: 1719618
- Update to version 7.0.11.9

* Wed Apr 14 2021 kekepower <kekepower> 7.0.11.7-1.mga9.tainted
+ Revision: 1715798
- Update to version 7.0.11.7

* Sat Apr 03 2021 kekepower <kekepower> 7.0.11.6-1.mga9.tainted
+ Revision: 1713038
- Update to version 7.0.11.6

* Mon Mar 29 2021 kekepower <kekepower> 7.0.11.5-1.mga9.tainted
+ Revision: 1711767
- Update to version 7.0.11.5

* Mon Mar 22 2021 kekepower <kekepower> 7.0.11.4-1.mga9
+ Revision: 1707242
- Update to version 7.0.11-4

* Fri Feb 26 2021 neoclust <neoclust> 7.0.10.62-1.mga9.tainted
+ Revision: 1692435
- New version 7.0.10.62
- New version 7.0.10.62: Fixes CVE-2021-2024[1346] (mga#28462)

* Tue Jan 12 2021 kekepower <kekepower> 7.0.10.57-1.mga8
+ Revision: 1671283
- Update to version 7.0.10.57

* Tue Jan 05 2021 neoclust <neoclust> 7.0.10.55-1.mga8
+ Revision: 1669016
- New version 7.0.10-55

* Sat Jan 02 2021 kekepower <kekepower> 7.0.10.54-1.mga8
+ Revision: 1668341
- Update to version 7.0.10.54

* Tue Dec 29 2020 kekepower <kekepower> 7.0.10.53-1.mga8
+ Revision: 1664835
- Update to version 7.0.10.53

* Sun Dec 20 2020 kekepower <kekepower> 7.0.10.52-1.mga8
+ Revision: 1662118
- Update to version 7.0.10.52

* Thu Dec 17 2020 kekepower <kekepower> 7.0.10.50-1.mga8.tainted
+ Revision: 1659916
- Update to version 7.0.10.50

* Tue Dec 15 2020 kekepower <kekepower> 7.0.10.49-1.mga8
+ Revision: 1657826
- Update to version 7.0.10.49

* Fri Dec 11 2020 kekepower <kekepower> 7.0.10.48-1.mga8.tainted
+ Revision: 1655407
- Update to version 7.0.10.48

* Wed Dec 09 2020 kekepower <kekepower> 7.0.10.47-1.mga8.tainted
+ Revision: 1655053
- Update to version 7.0.10.47

* Sun Dec 06 2020 kekepower <kekepower> 7.0.10.46-1.mga8
+ Revision: 1653408
- Update to version 7.0.10.46

* Tue Dec 01 2020 kekepower <kekepower> 7.0.10.45-1.mga8.tainted
+ Revision: 1651178
- Update to version 7.0.10.45

* Sat Nov 28 2020 kekepower <kekepower> 7.0.10.44-1.mga8.tainted
+ Revision: 1649978
- Update to version 7.0.10.44

* Tue Nov 24 2020 kekepower <kekepower> 7.0.10.43-1.mga8.tainted
+ Revision: 1648898
- Update to version 7.0.10.43

* Sat Nov 21 2020 kekepower <kekepower> 7.0.10.41-1.mga8.tainted
+ Revision: 1648239
- Update to version 7.0.10.41

* Wed Nov 18 2020 kekepower <kekepower> 7.0.10.39-1.mga8.tainted
+ Revision: 1647299
- Update to version 7.0.10.39

* Mon Nov 16 2020 kekepower <kekepower> 7.0.10.38-1.mga8
+ Revision: 1646558
- Update to version 7.0.10.38
- New lib major is 8

* Sun Nov 01 2020 kekepower <kekepower> 7.0.10.35-1.mga8
+ Revision: 1641372
- Update to version 7.0.10.35

* Fri Oct 09 2020 kekepower <kekepower> 7.0.10.34-1.mga8.tainted
+ Revision: 1632952
- Update to version 7.0.10.34

* Tue Oct 06 2020 kekepower <kekepower> 7.0.10.33-1.mga8
+ Revision: 1632288
- Update to version 7.0.10.33

* Wed Sep 30 2020 kekepower <kekepower> 7.0.10.31-1.mga8
+ Revision: 1631245
- Update to version 7.0.10.31

* Sun Sep 20 2020 kekepower <kekepower> 7.0.10.30-1.mga8
+ Revision: 1628953
- Update to version 7.0.10.30

* Mon Sep 07 2020 kekepower <kekepower> 7.0.10.29-1.mga8.tainted
+ Revision: 1623115
- Update to version 7.0.10.29

* Fri Aug 21 2020 kekepower <kekepower> 7.0.10.28-1.mga8.tainted
+ Revision: 1617731
- Update to version 7.0.10.28

* Sun Aug 16 2020 kekepower <kekepower> 7.0.10.27-1.mga8
+ Revision: 1614292
- Update to version 7.0.10.27

* Mon Aug 10 2020 kekepower <kekepower> 7.0.10.26-1.mga8.tainted
+ Revision: 1612423
- Update to version 7.0.10.26

* Sat Aug 01 2020 kekepower <kekepower> 7.0.10.25-1.mga8.tainted
+ Revision: 1610381
- Update to version 7.0.10.25

* Sun Jul 19 2020 kekepower <kekepower> 7.0.10.24-1.mga8
+ Revision: 1607208
- Update to version 7.0.10.24

* Sun Jul 05 2020 kekepower <kekepower> 7.0.10.23-1.mga8.tainted
+ Revision: 1602357
- Update to version 7.0.10.23

* Sun Jun 28 2020 kekepower <kekepower> 7.0.10.22-1.mga8.tainted
+ Revision: 1600124
- Update to version 7.0.10.22

* Fri Jun 26 2020 kekepower <kekepower> 7.0.10.21-1.mga8.tainted
+ Revision: 1599417
- Update to version 7.0.10.21

* Mon Jun 22 2020 kekepower <kekepower> 7.0.10.20-2.mga8
+ Revision: 1598375
- Update to version 7.0.10.20
+ umeabot <umeabot>
- Rebuild for perl 5.32

* Sat Jun 13 2020 kekepower <kekepower> 7.0.10.19-1.mga8.tainted
+ Revision: 1593178
- Update to version 7.0.10.19

* Wed Jun 10 2020 kekepower <kekepower> 7.0.10.18-1.mga8.tainted
+ Revision: 1591573
- Update to version 7.0.10.18

* Sun Jun 07 2020 kekepower <kekepower> 7.0.10.17-1.mga8.tainted
+ Revision: 1590888
- Update to version 7.0.10.17

* Mon Jun 01 2020 kekepower <kekepower> 7.0.10.16-1.mga8.tainted
+ Revision: 1589462
- Update to version 7.0.10.16

* Sun May 31 2020 kekepower <kekepower> 7.0.10.15-1.mga8
+ Revision: 1589169
- Update to version 7.0.10.15

* Sat May 23 2020 kekepower <kekepower> 7.0.10.14-1.mga8
+ Revision: 1587123
- Update to version 7.0.10.14

* Mon May 18 2020 kekepower <kekepower> 7.0.10.13-1.mga8.tainted
+ Revision: 1586041
- Update to version 7.0.10.13

* Sat May 16 2020 kekepower <kekepower> 7.0.10.12-1.mga8.tainted
+ Revision: 1584707
- Update to version 7.0.10.12

* Wed May 13 2020 kekepower <kekepower> 7.0.10.11-1.mga8
+ Revision: 1583463
- Update to version 7.0.10.11

* Tue Apr 28 2020 kekepower <kekepower> 7.0.10.10-1.mga8
+ Revision: 1573010
- Update to version 7.0.10.10

* Mon Apr 27 2020 kekepower <kekepower> 7.0.10.9-1.mga8.tainted
+ Revision: 1572405
- Update to version 7.0.10.9

* Sat Apr 25 2020 kekepower <kekepower> 7.0.10.8-1.mga8
+ Revision: 1572058
- Update to version 7.0.10.8

* Tue Apr 07 2020 kekepower <kekepower> 7.0.10.6-1.mga8.tainted
+ Revision: 1565367
- Update to version 7.0.10.6

* Mon Apr 06 2020 kekepower <kekepower> 7.0.10.4-1.mga8.tainted
+ Revision: 1565019
- Update to version 7.0.10.4

* Sun Mar 29 2020 kekepower <kekepower> 7.0.10.3-1.mga8.tainted
+ Revision: 1562150
- Update to version 7.0.10.3

* Tue Mar 24 2020 kekepower <kekepower> 7.0.10.2-3.mga8
+ Revision: 1559192
- Switch to pkgconfig() where possible

* Mon Mar 23 2020 joequant <joequant> 7.0.10.2-2.mga8
+ Revision: 1559171
- change binary to recommends to avoid pulling in graphics
  libraries in headless systems

* Sun Mar 22 2020 kekepower <kekepower> 7.0.10.2-1.mga8.tainted
+ Revision: 1559003
- Update to version 7.0.10.2

* Wed Mar 18 2020 kekepower <kekepower> 7.0.10.1-1.mga8.tainted
+ Revision: 1557840
- Update to version 7.0.10.1

* Sat Mar 07 2020 kekepower <kekepower> 7.0.10.0-1.mga8
+ Revision: 1554695
- Update to version 7.0.10.0

* Sun Mar 01 2020 kekepower <kekepower> 7.0.9.27-1.mga8.tainted
+ Revision: 1552657
- Update to version 7.0.9.27

* Tue Feb 25 2020 kekepower <kekepower> 7.0.9.26-1.mga8.tainted
+ Revision: 1550286
- Update to version 7.0.9.26

* Sat Feb 22 2020 kekepower <kekepower> 7.0.9.25-1.mga8
+ Revision: 1549434
- Update to version 7.0.9.25

* Thu Feb 20 2020 umeabot <umeabot> 7.0.9.24-2.mga8.tainted
+ Revision: 1547346
- Mageia 8 Mass Rebuild

* Wed Feb 19 2020 kekepower <kekepower> 7.0.9.24-1.mga8.tainted
+ Revision: 1544982
- Update to version 7.0.9.24

* Sat Feb 08 2020 kekepower <kekepower> 7.0.9.21-1.mga8
+ Revision: 1487951
- Update to version 7.0.9.21

* Thu Jan 30 2020 kekepower <kekepower> 7.0.9.20-1.mga8.tainted
+ Revision: 1485552
- Update to version 7.0.9.20

* Mon Jan 20 2020 kekepower <kekepower> 7.0.9.17-1.mga8.tainted
+ Revision: 1481676
- Update to version 7.0.9.17
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Jan 14 2020 kekepower <kekepower> 7.0.9.16-2.mga8
+ Revision: 1477854
- Update to version 7.0.9.16

* Sun Jan 12 2020 kekepower <kekepower> 7.0.9.15-2.mga8.tainted
+ Revision: 1477745
- Rebuild for armv7hl

* Sun Jan 12 2020 kekepower <kekepower> 7.0.9.15-1.mga8
+ Revision: 1477725
- Update to version 7.0.9.15

* Wed Jan 01 2020 kekepower <kekepower> 7.0.9.13-1.mga8.tainted
+ Revision: 1475184
- Update to version 7.0.9.13

* Mon Dec 30 2019 kekepower <kekepower> 7.0.9.12-1.mga8
+ Revision: 1474948
- Update to version 7.0.9.12

* Tue Oct 08 2019 kekepower <kekepower> 7.0.8.68-1.mga8.tainted
+ Revision: 1450563
- Update to version 7.0.8.68

* Sat Sep 21 2019 kekepower <kekepower> 7.0.8.65-1.mga8.tainted
+ Revision: 1444418
- Update to version 7.0.8.65

* Sat Sep 14 2019 kekepower <kekepower> 7.0.8.64-1.mga8
+ Revision: 1440864
- Update to version 7.0.8.64

* Sat Aug 31 2019 kekepower <kekepower> 7.0.8.63-2.mga8.tainted
+ Revision: 1436000
- Update to version 7.0.8.63

* Tue Aug 27 2019 tv <tv> 7.0.8.62-2.mga8.tainted
+ Revision: 1433279
- rebuild with perl-5.30

* Sun Aug 25 2019 kekepower <kekepower> 7.0.8.62-1.mga8.tainted
+ Revision: 1431899
- Update to version 7.0.8.62

* Wed Aug 21 2019 kekepower <kekepower> 7.0.8.61-1.mga8
+ Revision: 1431012
- Update to version 7.0.8.61

* Thu Aug 15 2019 kekepower <kekepower> 7.0.8.60-1.mga8.tainted
+ Revision: 1429383
- Update to version 7.0.8.60

* Mon Aug 05 2019 kekepower <kekepower> 7.0.8.59-1.mga8.tainted
+ Revision: 1427361
- Update to version 7.0.8.59

* Thu Aug 01 2019 kekepower <kekepower> 7.0.8.58-1.mga8.tainted
+ Revision: 1426686
- Update to version 7.0.8.58

* Sun Jul 21 2019 kekepower <kekepower> 7.0.8.56-1.mga8
+ Revision: 1423334
- Update to version 7.0.8.56

* Sat Jul 20 2019 kekepower <kekepower> 7.0.8.55-1.mga8.tainted
+ Revision: 1423197
- Update to version 7.0.8.55

* Thu Jul 18 2019 kekepower <kekepower> 7.0.8.54-1.mga8
+ Revision: 1422610
- Update to version 7.0.8.54

* Sat Jul 06 2019 kekepower <kekepower> 7.0.8.53-1.mga8.tainted
+ Revision: 1419060
- Update to version 7.0.8.53

* Tue Jul 02 2019 kekepower <kekepower> 7.0.8.51-1.mga8.tainted
+ Revision: 1417721
- Update to version 7.0.8.51

* Sat Jun 29 2019 kekepower <kekepower> 7.0.8.50-1.1.mga8.tainted
+ Revision: 1415901
- Update to version 7.0.8.50

* Wed May 08 2019 kekepower <kekepower> 7.0.8.44-1.mga7
+ Revision: 1396743
- Update to version 7.0.8.44

* Sun Apr 21 2019 kekepower <kekepower> 7.0.8.41-1.mga7
+ Revision: 1394145
- Update to version 7.0.8.41

* Sat Apr 13 2019 kekepower <kekepower> 7.0.8.40-1.mga7.tainted
+ Revision: 1389770
- Update to version 7.0.8.40

* Sun Apr 07 2019 kekepower <kekepower> 7.0.8.39-1.mga7.tainted
+ Revision: 1386668
- Update to version 7.0.8.39

* Wed Apr 03 2019 ns80 <ns80> 7.0.8.36-1.mga7
+ Revision: 1385525
- Update to version 7.0.8.36 for CVE-2019-10649 and CVE-2019-10650

* Tue Mar 26 2019 kekepower <kekepower> 7.0.8.35-1.mga7.tainted
+ Revision: 1380325
- Update to version 7.0.8.35

* Sat Mar 23 2019 kekepower <kekepower> 7.0.8.34-1.mga7.tainted
+ Revision: 1379718
- Update to version 7.0.8.34

* Mon Mar 11 2019 kekepower <kekepower> 7.0.8.33-1.mga7
+ Revision: 1373942
- Update to version 7.0.8.33

* Mon Feb 18 2019 kekepower <kekepower> 7.0.8.28-1.mga7.tainted
+ Revision: 1368214
- Update to version 7.0.8.28

* Sun Feb 10 2019 kekepower <kekepower> 7.0.8.27-1.mga7.tainted
+ Revision: 1364860
- Update to version 7.0.8.27

* Fri Feb 08 2019 kekepower <kekepower> 7.0.8.26-1.mga7
+ Revision: 1364187
- Update to version 7.0.8.26

* Mon Jan 28 2019 kekepower <kekepower> 7.0.8.25-2.mga7
+ Revision: 1361717
- Bump rel

* Mon Jan 28 2019 kekepower <kekepower> 7.0.8.25-1.1.mga7.tainted
+ Revision: 1361691
- Update to version 7.0.8.25

* Thu Jan 17 2019 kekepower <kekepower> 7.0.8.24-1.mga7.tainted
+ Revision: 1357795
- Update to version 7.0.8.24

* Sat Jan 05 2019 kekepower <kekepower> 7.0.8.23-1.mga7.tainted
+ Revision: 1349460
- Update to version 7.0.8.23

* Tue Jan 01 2019 kekepower <kekepower> 7.0.8.22-1.mga7.tainted
+ Revision: 1348348
- Update to version 7.0.8.22

* Thu Dec 27 2018 kekepower <kekepower> 7.0.8.21-1.mga7.tainted
+ Revision: 1345346
- Update to version 7.0.8.21

* Mon Dec 24 2018 kekepower <kekepower> 7.0.8.20-1.mga7.tainted
+ Revision: 1344829
- Update to version 7.0.8.20

* Thu Dec 20 2018 kekepower <kekepower> 7.0.8.19-1.mga7.tainted
+ Revision: 1343735
- Update to version 7.0.8.19

* Tue Dec 18 2018 kekepower <kekepower> 7.0.8.17-1.mga7.tainted
+ Revision: 1342587
- Update to versoin 7.0.8.17

* Mon Dec 10 2018 kekepower <kekepower> 7.0.8.16-1.mga7.tainted
+ Revision: 1339951
- Update to version 7.0.8.16

* Sun Dec 02 2018 kekepower <kekepower> 7.0.8.15-1.mga7.tainted
+ Revision: 1337617
- Update to version 7.0.8.15

* Thu Oct 25 2018 kekepower <kekepower> 7.0.8.14-2.mga7.tainted
+ Revision: 1325287
- Update to version 7.0.8.14

* Mon Oct 22 2018 kekepower <kekepower> 7.0.8.13-1.mga7.tainted
+ Revision: 1323943
- Update to version 7.0.8.13

* Tue Oct 16 2018 kekepower <kekepower> 7.0.8.12-3.mga7
+ Revision: 1321186
- Add support for heif/heic image format in tainted release

* Tue Oct 16 2018 daviddavid <daviddavid> 7.0.8.12-2.mga7
+ Revision: 1320825
- rebuild for new ilmbase 2.3.0

* Sun Sep 23 2018 kekepower <kekepower> 7.0.8.12-1.mga7
+ Revision: 1302302
- Update to version 7.0.8.12

* Wed Aug 29 2018 kekepower <kekepower> 7.0.8.11-1.mga7
+ Revision: 1255576
- Update to version 7.0.8.11

* Wed Aug 15 2018 kekepower <kekepower> 7.0.8.10-1.mga7
+ Revision: 1251671
- Update to version 7.0.8.10

* Sat Aug 11 2018 kekepower <kekepower> 7.0.8.9-1.mga7
+ Revision: 1251014
- Update to version 7.0.8.9

* Mon Aug 06 2018 guillomovitch <guillomovitch> 7.0.8.3-2.mga7
+ Revision: 1248347
- rebuild for perl 5.28

* Mon Jun 25 2018 kekepower <kekepower> 7.0.8.3-1.mga7
+ Revision: 1239688
- Update to version 7.0.8.3

* Tue Jun 19 2018 kekepower <kekepower> 7.0.8.2-1.mga7
+ Revision: 1238229
- Update to version 7.0.8.2

* Wed Jun 13 2018 kekepower <kekepower> 7.0.8.0-1.mga7
+ Revision: 1236720
- Update to version 7.0.8.0

* Mon Jun 11 2018 kekepower <kekepower> 7.0.7.39-1.mga7
+ Revision: 1236305
- Update to version 7.0.7.39

* Sun Jun 03 2018 kekepower <kekepower> 7.0.7.38-1.mga7
+ Revision: 1233782
- Update to version 7.0.7.38

* Thu May 31 2018 kekepower <kekepower> 7.0.7.37-1.mga7
+ Revision: 1233198
- Update to version 7.0.7.37

* Tue May 29 2018 kekepower <kekepower> 7.0.7.36-1.mga7
+ Revision: 1232959
- Update to version 7.0.7.36

* Sun May 27 2018 wally <wally> 7.0.7.34-2.mga7
+ Revision: 1232418
- rebuild for openexr 2.2.1

* Mon May 21 2018 kekepower <kekepower> 7.0.7.34-1.mga7
+ Revision: 1230871
- Update to version 7.0.7.34

* Thu May 10 2018 shlomif <shlomif> 7.0.7.31-1.mga7
+ Revision: 1228141
- New version

* Fri May 04 2018 kekepower <kekepower> 7.0.7.30-1.mga7
+ Revision: 1226115
- Update to version 7.0.7.30

* Wed May 02 2018 kekepower <kekepower> 7.0.7.29-1.mga7
+ Revision: 1224482
- Update to version 7.0.7.29

* Fri Mar 30 2018 kekepower <kekepower> 7.0.7.28-1.mga7
+ Revision: 1213622
- Update to version 7.0.7-28
+ wally <wally>
- build without old and long dead lcms 1.x

* Mon Mar 19 2018 kekepower <kekepower> 7.0.7.27-1.mga7
+ Revision: 1210383
- Update to version 7.0.7-27

* Wed Mar 14 2018 kekepower <kekepower> 7.0.7.26-1.mga7
+ Revision: 1209270
- Update to version 7.0.7-26

* Sun Mar 04 2018 kekepower <kekepower> 7.0.7.25-1.mga7
+ Revision: 1206558
- Update to version 7.0.7-25

* Tue Feb 27 2018 kekepower <kekepower> 7.0.7.24-1.mga7
+ Revision: 1205477
- Update to version 7.0.7-24

* Fri Jan 26 2018 kekepower <kekepower> 7.0.7.22-1.mga7
+ Revision: 1197244
- Update to version 7.0.7-22
+ wally <wally>
- clean old and unneeded obsoletes/conflicts

* Thu Jan 18 2018 kekepower <kekepower> 7.0.7.21-1.mga7
+ Revision: 1194390
- Update to version 7.0.7-21
- Rebased patches
- Removed old patches
- Cleaned up the spec file

* Wed Dec 27 2017 luigiwalser <luigiwalser> 6.9.9.28-1.mga7
+ Revision: 1185537
- cpp major is now 8
- library major is now 5
- 6.9.9-28

* Thu Aug 31 2017 pterjan <pterjan> 6.9.8.7-3.mga7
+ Revision: 1150266
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 6.9.8.7-2.mga7
+ Revision: 1127028
- Rebuild against new Perl 5.26

* Sat May 27 2017 shlomif <shlomif> 6.9.8.7-1.mga6
+ Revision: 1105181
- New version 6.9.8-7 fixing CVEs ( MGA#19078 ).

* Mon Sep 26 2016 luigiwalser <luigiwalser> 6.9.5.10-1.mga6
+ Revision: 1056786
- 6.9.5-10

* Wed Aug 10 2016 luigiwalser <luigiwalser> 6.9.5.5-1.mga6
+ Revision: 1045272
- 6.9.5-5

* Fri Jul 15 2016 luigiwalser <luigiwalser> 6.9.5.2-1.mga6
+ Revision: 1042157
- 6.9.5-2

* Wed Jul 06 2016 shlomif <shlomif> 6.9.5.0-1.mga6
+ Revision: 1039187
- New version 6.9.5-0 with some fixes.

* Thu Jun 23 2016 luigiwalser <luigiwalser> 6.9.4.10-1.mga6
+ Revision: 1037353
- 6.9.4-10

* Tue Jun 07 2016 luigiwalser <luigiwalser> 6.9.4.8-1.mga6
+ Revision: 1020626
- 6.9.4-8

* Sat Jun 04 2016 luigiwalser <luigiwalser> 6.9.4.7-1.mga6
+ Revision: 1020244
- 6.9.4-7

* Wed Jun 01 2016 luigiwalser <luigiwalser> 6.9.4.6-1.mga6
+ Revision: 1019711
- 6.9.4-6 (fixes CVE-2016-5118)

* Mon May 30 2016 luigiwalser <luigiwalser> 6.9.4.5-1.mga6
+ Revision: 1019453
- 6.9.4-5

* Tue May 17 2016 luigiwalser <luigiwalser> 6.9.4.2-1.mga6
+ Revision: 1016542
- 6.9.4-2

* Wed May 11 2016 luigiwalser <luigiwalser> 6.9.4.1-1.mga6
+ Revision: 1013188
- 6.9.4-1

* Mon May 09 2016 luigiwalser <luigiwalser> 6.9.4.0-1.mga6
+ Revision: 1011273
- 6.9.4-0

* Wed May 04 2016 luigiwalser <luigiwalser> 6.9.3.10-1.mga6
+ Revision: 1009374
- 6.9.3-10

* Mon May 02 2016 luigiwalser <luigiwalser> 6.9.3.9-1.mga6
+ Revision: 1008679
- 6.9.3-9

* Tue Apr 12 2016 luigiwalser <luigiwalser> 6.9.3.8-1.mga6
+ Revision: 1000649
- 6.9.3-8

* Tue Mar 01 2016 luigiwalser <luigiwalser> 6.9.3.6-1.mga6
+ Revision: 981177
- 6.9.3-6

* Mon Feb 22 2016 luigiwalser <luigiwalser> 6.9.3.5-1.mga6
+ Revision: 976050
- 6.9.3-5

* Mon Feb 15 2016 luigiwalser <luigiwalser> 6.9.3.4-1.mga6
+ Revision: 961625
- 6.9.3-4

* Mon Feb 08 2016 luigiwalser <luigiwalser> 6.9.3.3-1.mga6
+ Revision: 950862
- 6.9.3-3

* Sat Jan 23 2016 luigiwalser <luigiwalser> 6.9.3.2-1.mga6
+ Revision: 926679
- 6.9.3-2

* Sun Jan 03 2016 luigiwalser <luigiwalser> 6.9.3.0-1.mga6
+ Revision: 919074
- 6.9.3-0

* Sat Jan 02 2016 luigiwalser <luigiwalser> 6.9.2.8-2.mga6
+ Revision: 918202
- rebuild for libwebp

* Wed Dec 09 2015 luigiwalser <luigiwalser> 6.9.2.8-1.mga6
+ Revision: 909131
- 6.9.2-8

* Fri Nov 27 2015 fwang <fwang> 6.9.2.6-1.mga6
+ Revision: 906382
- 6.9.2-6

* Sun Nov 01 2015 fwang <fwang> 6.9.2.5-1.mga6
+ Revision: 897096
- 6.9.2-5

* Tue Oct 06 2015 fwang <fwang> 6.9.2.3-1.mga6
+ Revision: 886584
- 6.9.2-3

* Wed Aug 26 2015 fwang <fwang> 6.9.2.0-1.mga6
+ Revision: 869566
- 6.9.2.0
+ daviddavid <daviddavid>
- rebuild for new gcc 5.2.1

* Fri Aug 14 2015 shlomif <shlomif> 6.9.1.6-4.mga6
+ Revision: 864615
- dot-spec cleanups
- Fix JPEG2000 support (MGA#16585)

* Sat Jun 27 2015 tv <tv> 6.9.1.6-3.mga6
+ Revision: 846140
- rebuild with soname-ified perl

* Tue Jun 23 2015 fwang <fwang> 6.9.1.6-2.mga6
+ Revision: 840457
- rebuild for perl-5.22

* Mon Jun 22 2015 fwang <fwang> 6.9.1.6-1.mga6
+ Revision: 839137
- bump cpp libmajor
- new version 6.9.1-6
  debian patches are merged into upstream

* Fri Jan 02 2015 luigiwalser <luigiwalser> 6.8.9.9-4.mga5
+ Revision: 808196
- add another fix from debian (fix regression in xpm crash fix)

* Wed Dec 24 2014 luigiwalser <luigiwalser> 6.8.9.9-3.mga5
+ Revision: 805440
- add upstream patches via debian to fix various security issues
- remove obsolete patch that was not being applied anymore
- adjust patch level of existing patches to use apply_patches macro

* Fri Nov 14 2014 luigiwalser <luigiwalser> 6.8.9.9-2.mga5
+ Revision: 796909
- add upstream patch to fix CVE-2014-8716

* Wed Oct 29 2014 luigiwalser <luigiwalser> 6.8.9.9-1.mga5
+ Revision: 794447
- 6.8.9-9

* Wed Oct 15 2014 umeabot <umeabot> 6.8.9.7-7.mga5
+ Revision: 745726
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 6.8.9.7-6.mga5
+ Revision: 726487
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 6.8.9.7-5.mga5
+ Revision: 680485
- Mageia 5 Mass Rebuild

* Mon Aug 25 2014 fwang <fwang> 6.8.9.7-4.mga5
+ Revision: 667291
- br openexr

* Mon Aug 25 2014 fwang <fwang> 6.8.9.7-3.mga5
+ Revision: 667287
- force x86-64

* Mon Aug 25 2014 fwang <fwang> 6.8.9.7-2.mga5
+ Revision: 667270
- hardcode gcc build arch

* Sun Aug 17 2014 fwang <fwang> 6.8.9.7-1.mga5
+ Revision: 664889
- update libmajor
- 6.8.9-7

* Tue Jun 03 2014 pterjan <pterjan> 6.8.9.1-2.mga5
+ Revision: 630780
- Rebuild for perl 5.20

* Fri May 30 2014 fwang <fwang> 6.8.9.1-1.mga5
+ Revision: 627844
- 6.8.9-1

* Wed Apr 23 2014 fwang <fwang> 6.8.9.0-1.mga5
+ Revision: 617494
- 6.8.9-0

* Tue Apr 01 2014 fwang <fwang> 6.8.8.10-1.mga5
+ Revision: 611081
- 6.8.8-10

* Sat Mar 15 2014 fwang <fwang> 6.8.8.8-1.mga5
+ Revision: 603944
- 6.8.8-8

* Sat Feb 15 2014 luigiwalser <luigiwalser> 6.8.8.6-2.mga5
+ Revision: 592106
- rebuild for libwebp

* Fri Feb 14 2014 fwang <fwang> 6.8.8.6-1.mga5
+ Revision: 591061
- 6.8.8-6

* Mon Feb 10 2014 fwang <fwang> 6.8.8.5-1.mga5
+ Revision: 587856
- 6.8.8-5

* Wed Feb 05 2014 fwang <fwang> 6.8.8.4-1.mga5
+ Revision: 583111
- update lib major
- new version 6.8.8-4

* Mon Oct 21 2013 umeabot <umeabot> 6.8.7.0-2.mga4
+ Revision: 537701
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 fwang <fwang> 6.8.7.0-1.mga4
+ Revision: 487526
- new version 6.8.7-0

* Thu Sep 19 2013 fwang <fwang> 6.8.6.10-1.mga4
+ Revision: 481463
- update cpp major
- new version 6.8.6-10

* Sun Sep 01 2013 fwang <fwang> 6.8.6.9-1.mga4
+ Revision: 473794
- new version 6.8.6-9

* Wed Aug 07 2013 fwang <fwang> 6.8.6.8-1.mga4
+ Revision: 464393
- split cpp lib
- new version 6.8.6-8

* Sat Jun 08 2013 fwang <fwang> 6.8.5.10-1.mga4
+ Revision: 440491
- new version 6.8.5-10

* Sun Jun 02 2013 fwang <fwang> 6.8.5.8-3.mga4
+ Revision: 434651
- rebuild for new libpng

* Wed May 29 2013 tv <tv> 6.8.5.8-2.mga4
+ Revision: 430134
- rebuild for new perl

* Tue May 28 2013 fwang <fwang> 6.8.5.8-1.mga4
+ Revision: 429127
- new version 6.8.5.8

* Tue May 28 2013 fwang <fwang> 6.8.5.7-2.mga4
+ Revision: 429126
- fix wrong link

* Tue May 28 2013 fwang <fwang> 6.8.5.7-1.mga4
+ Revision: 429121
- update libname
- update file list
- update file list
- disable undefined
+ spuhler <spuhler>
- upgrade to 6.8.5-7
- rediffed against 6.8.5-7

* Sat Jan 12 2013 umeabot <umeabot> 6.8.1.1-2.mga3
+ Revision: 354290
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Editors -> Graphics/Editors and Converters

* Sat Dec 22 2012 fwang <fwang> 6.8.1.1-1.mga3
+ Revision: 333783
- new version 6.8.1-1

* Sat Dec 15 2012 fwang <fwang> 6.8.0.10-1.mga3
+ Revision: 331107
- new version 6.8.0-10

* Fri Dec 14 2012 fwang <fwang> 6.8.0.9-2.mga3
+ Revision: 330735
- create compatible symlinks

* Fri Dec 14 2012 fwang <fwang> 6.8.0.9-1.mga3
+ Revision: 330723
- update file list
- bump libmajor
- new version 6.8.0-9

* Fri Oct 12 2012 fwang <fwang> 6.8.0.0-1.mga3
+ Revision: 305058
- br webp
- bump libmajor
- new verrsion 6.8.0.0

* Sun Oct 07 2012 fwang <fwang> 6.7.9.10-1.mga3
+ Revision: 303128
- update rpm group
- new version 6.7.9-10

* Sat Sep 29 2012 fwang <fwang> 6.7.9.8-1.mga3
+ Revision: 299623
- update group
- new version 6.7.9-8

* Sun Sep 23 2012 fwang <fwang> 6.7.9.7-1.mga3
+ Revision: 296869
- new version 6.7.9-7

* Mon Sep 17 2012 fwang <fwang> 6.7.9.6-1.mga3
+ Revision: 294771
- new version 6.7.9-6

* Fri Sep 14 2012 fwang <fwang> 6.7.9.5-1.mga3
+ Revision: 293741
- new version 6.7.9-5

* Sat Sep 01 2012 fwang <fwang> 6.7.9.3-1.mga3
+ Revision: 286870
- new version 6.7.9-3

* Mon Aug 27 2012 fwang <fwang> 6.7.9.2-1.mga3
+ Revision: 284616
- new version 6.7.9-2
- new version 6.7.9-2

* Fri Aug 17 2012 fwang <fwang> 6.7.9.0-1.mga3
+ Revision: 281734
- new version 6.7.9-0

* Wed Aug 01 2012 fwang <fwang> 6.7.8.7-1.mga3
+ Revision: 277150
- new version 6.7.8-7

* Tue Jul 24 2012 fwang <fwang> 6.7.8.6-1.mga3
+ Revision: 273919
- new version 6.7.8-6

* Thu Jul 19 2012 fwang <fwang> 6.7.8.4-1.mga3
+ Revision: 272537
- new version 6.7.8-4

* Thu Jul 05 2012 fwang <fwang> 6.7.8.1-1.mga3
+ Revision: 267830
- new version 6.7.8-1

* Sat Jun 30 2012 fwang <fwang> 6.7.8.0-1.mga3
+ Revision: 265236
- new version 6.8.8-0

* Fri Jun 29 2012 fwang <fwang> 6.7.7.10-1.mga3
+ Revision: 264853
- new version 6.7.7-10

* Tue Jun 26 2012 fwang <fwang> 6.7.7.9-2.mga3
+ Revision: 263802
- add more br

* Tue Jun 26 2012 fwang <fwang> 6.7.7.9-1.mga3
+ Revision: 263796
- new version 6.7.7-9

* Sat Jun 02 2012 fwang <fwang> 6.7.7.5-1.mga3
+ Revision: 253233
- new version 6.7.7-5

* Thu May 31 2012 fwang <fwang> 6.7.7.4-1.mga3
+ Revision: 251928
- new version 6.7.7-4

* Thu May 31 2012 blino <blino> 6.7.7.2-3.mga3
+ Revision: 251919
- simplify using autoreconf
- copy missing automake files
- buildrequire subversion (for svnversion)
+ tv <tv>
- rebuild for new perl

* Mon May 28 2012 fwang <fwang> 6.7.7.2-1.mga3
+ Revision: 247736
- real fix patches
- drop invalid patch
- update file list
- update file list
- update file list
- update file list
- drop merged patches
- new version 6.7.7-2

* Tue May 01 2012 luigiwalser <luigiwalser> 6.7.5.10-2.mga2
+ Revision: 234416
- fix CVE-2012-0259, CVE-2012-0260, CVE-2012-1798, CVE-2012-1610 (from debian)

* Tue Mar 06 2012 fwang <fwang> 6.7.5.10-1.mga2
+ Revision: 219461
- new version 6.7.5-10

* Sat Mar 03 2012 fwang <fwang> 6.7.5.8-1.mga2
+ Revision: 217114
- new version 6.7.5-8

* Sun Feb 26 2012 fwang <fwang> 6.7.5.7-1.mga2
+ Revision: 214996
- new version 6.7.5-7
+ obgr_seneca <obgr_seneca>
- removed mentioning of tetex and replaced it by texlive

* Tue Feb 07 2012 fwang <fwang> 6.7.5.3-1.mga2
+ Revision: 205839
- new version 6.7.5-3

* Mon Feb 06 2012 fwang <fwang> 6.7.5.2-1.mga2
+ Revision: 205202
- new version 6.7.5-2
- move some manpages into correct package
- don't know how these requires come from

* Sun Jan 29 2012 fwang <fwang> 6.7.5.0-1.mga2
+ Revision: 202824
- new version 6.7.5.0
- force use so to load module

* Thu Jan 26 2012 fwang <fwang> 6.7.4.10-1.mga2
+ Revision: 201718
- new version 6.7.4-10

* Wed Jan 25 2012 fwang <fwang> 6.7.4.9-1.mga2
+ Revision: 200695
- new version 6.7.4-9

* Sun Jan 22 2012 fwang <fwang> 6.7.4.8-1.mga2
+ Revision: 199724
- new version 6.7.4-8

* Mon Jan 16 2012 fwang <fwang> 6.7.4.7-1.mga2
+ Revision: 196902
- new version 6.7.4-7

* Thu Jan 12 2012 fwang <fwang> 6.7.4.6-1.mga2
+ Revision: 195261
- new version 6.7.4.6

* Mon Jan 02 2012 fwang <fwang> 6.7.4.4-1.mga2
+ Revision: 189550
- new version 6.7.4-4

* Tue Dec 27 2011 fwang <fwang> 6.7.4.2-1.mga2
+ Revision: 188092
- new version 6.7.4-2

* Fri Dec 23 2011 fwang <fwang> 6.7.4.1-3.mga2
+ Revision: 186337
- rebuild for new libtiff

* Thu Dec 22 2011 fwang <fwang> 6.7.4.1-2.mga2
+ Revision: 186082
- rebuild for new libtiff

* Thu Dec 22 2011 fwang <fwang> 6.7.4.1-1.mga2
+ Revision: 185989
- build with modules as what fedora does
- new version 6.7.4-1

* Sun Dec 11 2011 fwang <fwang> 6.7.4.0-1.mga2
+ Revision: 180522
- new version 6.7.4-0

* Sun Dec 04 2011 fwang <fwang> 6.7.3.10-1.mga2
+ Revision: 175843
- new version 6.7.3-10

* Mon Nov 28 2011 fwang <fwang> 6.7.3.9-1.mga2
+ Revision: 173783
- new version 6.7.3-9

* Sun Nov 27 2011 fwang <fwang> 6.7.3.8-1.mga2
+ Revision: 173006
- new version 6.7.3-8

* Sun Nov 20 2011 fwang <fwang> 6.7.3.7-1.mga2
+ Revision: 169605
- new version 6.7.3-7

* Wed Nov 16 2011 fwang <fwang> 6.7.3.6-1.mga2
+ Revision: 168077
- update file list
- new version 6.7.3-6

* Fri Nov 11 2011 fwang <fwang> 6.7.3.5-1.mga2
+ Revision: 166825
- new version 6.7.3-5

* Sun Nov 06 2011 fwang <fwang> 6.7.3.4-1.mga2
+ Revision: 164123
- new version 6.7.3-4
- new version 6.7.3-3

* Sun Oct 23 2011 fwang <fwang> 6.7.3.2-1.mga2
+ Revision: 157475
- drop unused patch

* Thu Oct 20 2011 zezinho <zezinho> 6.7.3.1-1.mga2
+ Revision: 156885
- new version

* Wed Oct 12 2011 fwang <fwang> 6.7.3.0-1.mga2
+ Revision: 154005
- new version 6.7.3-0

* Mon Sep 26 2011 fwang <fwang> 6.7.2.9-1.mga2
+ Revision: 147983
- new version 6.7.2-9

* Sun Sep 25 2011 fwang <fwang> 6.7.2.8-1.mga2
+ Revision: 147713
- new version 6.7.2-8

* Sun Sep 18 2011 fwang <fwang> 6.7.2.7-1.mga2
+ Revision: 144787
- new version 6.7.2-7

* Thu Sep 15 2011 fwang <fwang> 6.7.2.6-1.mga2
+ Revision: 143816
- new version 6.7.2-6

* Mon Sep 12 2011 fwang <fwang> 6.7.2.5-1.mga2
+ Revision: 142739
- update libmajor
- new version 6.7.2-5

* Sat Sep 10 2011 fwang <fwang> 6.7.2.3-3.mga2
+ Revision: 142181
- rebuild for new libpng

* Wed Sep 07 2011 fwang <fwang> 6.7.2.3-2.mga2
+ Revision: 140897
- new version 6.7.2-3

* Fri Sep 02 2011 tv <tv> 6.7.2.1-2.mga2
+ Revision: 137819
- make the huge doc subpackage be noarch

* Wed Aug 31 2011 fwang <fwang> 6.7.2.1-1.mga2
+ Revision: 136860
- new version 6.7.2-1
- new version 6.7.2-0
- new version 6.7.1-10
- new version 6.7.1-9
- new version 6.7.1-8
- new version 6.7.1-7
- new version 6.7.1-6
- new version 6.7.1-5
- new version 6.7.1-4
- new version 6.7.1-3
- new version 6.7.1-1
- new version 6.7.1-0

* Sun Jul 10 2011 fwang <fwang> 6.7.1.0-1.mga2
+ Revision: 121583
- new version 6.7.1-0

* Tue Jul 05 2011 fwang <fwang> 6.7.0.10-2.mga2
+ Revision: 118645
- new version 6.7.0-10

* Tue Jun 28 2011 fwang <fwang> 6.7.0.9-2.mga2
+ Revision: 115130
- rebuild for new graphviz

* Mon Jun 27 2011 fwang <fwang> 6.7.0.9-1.mga2
+ Revision: 114294
- new version 6.7.0-9

* Thu Jun 16 2011 fwang <fwang> 6.7.0.8-1.mga2
+ Revision: 108150
- update docdirpatch
- New version 6.7.0-8
- revise br

* Sun Jun 12 2011 sander85 <sander85> 6.6.6.10-6.mga2
+ Revision: 104679
- Rebuild for perl 5.14

* Sat May 21 2011 ahmad <ahmad> 6.6.6.10-5.mga1
+ Revision: 99994
- Replace a reference to Mandriva with Mageia

* Sat May 14 2011 anssi <anssi> 6.6.6.10-4.mga1
+ Revision: 98658
- rebuild due to old references in .la files

* Tue Apr 26 2011 wally <wally> 6.6.6.10-3.mga1
+ Revision: 91746
- fix desktop file name (mga#954)

* Wed Jan 19 2011 jquelin <jquelin> 6.6.6.10-2.mga1
+ Revision: 23775
- rebuild

* Fri Jan 14 2011 mikala <mikala> 6.6.6.10-1.mga1
+ Revision: 17591
- Enable bootstrap
+ pterjan <pterjan>
- Drop obsolete scriptlets
- imported package imagemagick


* Sun Jan 02 2011 Funda Wang <fwang@mandriva.org> 6.6.6.10-1mdv2011.0
+ Revision: 627494
- New version 6.6.6-10

* Sat Jan 01 2011 Funda Wang <fwang@mandriva.org> 6.6.6.9-1mdv2011.0
+ Revision: 626953
- new version 6.6.6-9

* Thu Dec 30 2010 Funda Wang <fwang@mandriva.org> 6.6.6.8-1mdv2011.0
+ Revision: 626269
- new version 6.6.6-8

* Sun Dec 26 2010 Funda Wang <fwang@mandriva.org> 6.6.6.7-1mdv2011.0
+ Revision: 625144
- new verison 6.6.6-7

* Mon Dec 20 2010 Funda Wang <fwang@mandriva.org> 6.6.6.6-1mdv2011.0
+ Revision: 623224
- new version 6.6.6-6

* Tue Dec 14 2010 Funda Wang <fwang@mandriva.org> 6.6.6.5-1mdv2011.0
+ Revision: 621734
- new version 6.6.6-5

* Sun Dec 05 2010 Funda Wang <fwang@mandriva.org> 6.6.6.3-1mdv2011.0
+ Revision: 609581
- new version 6.6.6-3

* Thu Dec 02 2010 Funda Wang <fwang@mandriva.org> 6.6.6.2-1mdv2011.0
+ Revision: 604665
- new version 6.6.6-2

* Mon Nov 29 2010 Funda Wang <fwang@mandriva.org> 6.6.6.1-1mdv2011.0
+ Revision: 602959
- new version 6.6.6-1

* Sun Nov 28 2010 Funda Wang <fwang@mandriva.org> 6.6.6.0-1mdv2011.0
+ Revision: 602173
- 6.6.6.0

* Tue Nov 23 2010 Funda Wang <fwang@mandriva.org> 6.6.5.10-1mdv2011.0
+ Revision: 599890
- new version 6.6.5-10

* Sun Nov 21 2010 Funda Wang <fwang@mandriva.org> 6.6.5.9-1mdv2011.0
+ Revision: 599328
- new version 6.6.5-9

* Fri Nov 12 2010 Funda Wang <fwang@mandriva.org> 6.6.5.8-1mdv2011.0
+ Revision: 596421
- new version 6.6.5-8
- new version 6.6.5-7

* Sat Nov 06 2010 Funda Wang <fwang@mandriva.org> 6.6.5.6-1mdv2011.0
+ Revision: 594128
- new version 6.6.5-6

* Sun Oct 31 2010 Funda Wang <fwang@mandriva.org> 6.6.5.5-1mdv2011.0
+ Revision: 590736
- new version 6.6.5-5

* Tue Oct 26 2010 Funda Wang <fwang@mandriva.org> 6.6.5.4-1mdv2011.0
+ Revision: 589407
- new version 6.6.5-4

* Sun Oct 24 2010 Funda Wang <fwang@mandriva.org> 6.6.5.3-1mdv2011.0
+ Revision: 587901
- patch21 not needed anymore
- new version 6.6.5-3

* Fri Oct 22 2010 Funda Wang <fwang@mandriva.org> 6.6.5.2-1mdv2011.0
+ Revision: 587211
- new version 6.6.5-2

* Wed Oct 20 2010 Funda Wang <fwang@mandriva.org> 6.6.5.1-1mdv2011.0
+ Revision: 586868
- new version 6.6.5-1

* Thu Oct 14 2010 Funda Wang <fwang@mandriva.org> 6.6.5.0-1mdv2011.0
+ Revision: 585631
- new version 6.6.5-0

* Mon Oct 11 2010 Funda Wang <fwang@mandriva.org> 6.6.4.10-1mdv2011.0
+ Revision: 584868
- new version 6.6.4-10

* Wed Oct 06 2010 Funda Wang <fwang@mandriva.org> 6.6.4.9-1mdv2011.0
+ Revision: 583356
- new verson 6.6.4-9

* Fri Oct 01 2010 Funda Wang <fwang@mandriva.org> 6.6.4.8-1mdv2011.0
+ Revision: 582218
- fix build
- new version 6.6.4-8
- new version 6.6.4-7
- new version 6.6.4-6

* Wed Sep 22 2010 Funda Wang <fwang@mandriva.org> 6.6.4.5-1mdv2011.0
+ Revision: 580498
- new version 6.6.4-5

* Sun Sep 19 2010 Funda Wang <fwang@mandriva.org> 6.6.4.4-1mdv2011.0
+ Revision: 579763
- new version 6.6.4-4

* Sat Sep 18 2010 Funda Wang <fwang@mandriva.org> 6.6.4.3-1mdv2011.0
+ Revision: 579313
- new version 6.6.4-3

* Wed Sep 15 2010 Funda Wang <fwang@mandriva.org> 6.6.4.2-1mdv2011.0
+ Revision: 578520
- new version 6.6.4-2

* Mon Sep 13 2010 Funda Wang <fwang@mandriva.org> 6.6.4.1-1mdv2011.0
+ Revision: 577845
- new version 6.6.4-1

* Sun Sep 05 2010 Funda Wang <fwang@mandriva.org> 6.6.4.0-1mdv2011.0
+ Revision: 576059
- new version 6.6.4-0

* Wed Sep 01 2010 Funda Wang <fwang@mandriva.org> 6.6.3.10-1mdv2011.0
+ Revision: 574997
- new version 6.6.3-10

* Mon Aug 23 2010 Funda Wang <fwang@mandriva.org> 6.6.3.9-1mdv2011.0
+ Revision: 572099
- new version 6.6.3-9

* Sun Aug 22 2010 Funda Wang <fwang@mandriva.org> 6.6.3.8-1mdv2011.0
+ Revision: 571789
- new version 6.6.3-8

* Fri Aug 20 2010 Funda Wang <fwang@mandriva.org> 6.6.3.7-1mdv2011.0
+ Revision: 571403
- new version 6.6.3-7

* Sun Aug 15 2010 Funda Wang <fwang@mandriva.org> 6.6.3.6-1mdv2011.0
+ Revision: 569908
- new version 6.6.3-6

* Sat Aug 14 2010 Funda Wang <fwang@mandriva.org> 6.6.3.5-1mdv2011.0
+ Revision: 569514
- new version 6.6.3-5

* Sat Aug 07 2010 Funda Wang <fwang@mandriva.org> 6.6.3.3-1mdv2011.0
+ Revision: 567411
- patch22 merged upstream
- new version 6.6.3-3

* Mon Aug 02 2010 Funda Wang <fwang@mandriva.org> 6.6.3.2-1mdv2011.0
+ Revision: 564918
- Makefile should use tab instead space
- new version 6.6.3-2

* Wed Jul 28 2010 Funda Wang <fwang@mandriva.org> 6.6.3.1-1mdv2011.0
+ Revision: 562561
- new version 6.6.3-1

* Thu Jul 22 2010 Jérôme Quelin <jquelin@mandriva.org> 6.6.3.0-2mdv2011.0
+ Revision: 556777
- perl 5.12 rebuild

* Sat Jul 10 2010 Funda Wang <fwang@mandriva.org> 6.6.3.0-1mdv2011.0
+ Revision: 549961
- new libmajor
- New version 6.6.3-0

* Wed Apr 28 2010 Christophe Fergeau <cfergeau@mandriva.com> 6.6.1.5-2mdv2010.1
+ Revision: 540029
- rebuild so that shared libraries are properly stripped again

* Sat Apr 24 2010 Funda Wang <fwang@mandriva.org> 6.6.1.5-1mdv2010.1
+ Revision: 538410
- new version 6.6.1-5

* Sun Apr 18 2010 Funda Wang <fwang@mandriva.org> 6.6.1.4-1mdv2010.1
+ Revision: 536084
- new version 6.6.1-4

* Mon Apr 12 2010 Funda Wang <fwang@mandriva.org> 6.6.1.2-1mdv2010.1
+ Revision: 533694
- new version 6.6.1-2

* Fri Apr 09 2010 Funda Wang <fwang@mandriva.org> 6.6.1.1-1mdv2010.1
+ Revision: 533313
- new version 6.6.1-1

* Mon Apr 05 2010 Funda Wang <fwang@mandriva.org> 6.6.1.0-1mdv2010.1
+ Revision: 531523
- new version 6.6.1-0

* Sat Mar 27 2010 Funda Wang <fwang@mandriva.org> 6.6.0.10-1mdv2010.1
+ Revision: 527890
- new version 6.6.0-10

* Thu Mar 25 2010 Funda Wang <fwang@mandriva.org> 6.6.0.9-1mdv2010.1
+ Revision: 527326
- new version 6.6.0-9

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 6.6.0.8-1mdv2010.1
+ Revision: 525949
- new version 6.6.0-8

* Fri Mar 19 2010 Funda Wang <fwang@mandriva.org> 6.6.0.7-1mdv2010.1
+ Revision: 525188
- new version 6.6.0-7

* Wed Mar 17 2010 Funda Wang <fwang@mandriva.org> 6.6.0.6-1mdv2010.1
+ Revision: 522676
- new version 6.6.0-6

* Sat Mar 13 2010 Funda Wang <fwang@mandriva.org> 6.6.0.5-1mdv2010.1
+ Revision: 518642
- new version 6.6.0-5

* Tue Mar 09 2010 Funda Wang <fwang@mandriva.org> 6.6.0.4-1mdv2010.1
+ Revision: 516824
- new version 6.6.0-4

* Sun Mar 07 2010 Funda Wang <fwang@mandriva.org> 6.6.0.3-1mdv2010.1
+ Revision: 515318
- new version 6.6.0-3

* Sat Mar 06 2010 Funda Wang <fwang@mandriva.org> 6.6.0.2-1mdv2010.1
+ Revision: 514913
- new version 6.6.0-2

* Fri Mar 05 2010 Funda Wang <fwang@mandriva.org> 6.6.0.1-1mdv2010.1
+ Revision: 514380
- New version 6.6.0-1

* Sat Feb 27 2010 Funda Wang <fwang@mandriva.org> 6.6.0.0-1mdv2010.1
+ Revision: 512186
- new version 6.6.0.0

* Tue Feb 23 2010 Funda Wang <fwang@mandriva.org> 6.5.9.10-1mdv2010.1
+ Revision: 509886
- new version 6.5.9-10

* Sun Feb 21 2010 Funda Wang <fwang@mandriva.org> 6.5.9.9-1mdv2010.1
+ Revision: 508916
- new version 6.5.9-9

* Fri Feb 19 2010 Funda Wang <fwang@mandriva.org> 6.5.9.8-1mdv2010.1
+ Revision: 507963
- new version 6.5.9-8

* Thu Feb 18 2010 Funda Wang <fwang@mandriva.org> 6.5.9.7-1mdv2010.1
+ Revision: 507367
- new version 6.5.9-7

* Tue Feb 16 2010 Funda Wang <fwang@mandriva.org> 6.5.9.6-1mdv2010.1
+ Revision: 506599
- new version 6.5.9-6

* Sun Feb 14 2010 Funda Wang <fwang@mandriva.org> 6.5.9.5-1mdv2010.1
+ Revision: 505850
- new version 6.5.9-5

* Sat Feb 13 2010 Funda Wang <fwang@mandriva.org> 6.5.9.4-1mdv2010.1
+ Revision: 505507
- new version 5.6.9-4

* Mon Feb 08 2010 Funda Wang <fwang@mandriva.org> 6.5.9.3-1mdv2010.1
+ Revision: 502221
- New version 6.5.9-3

* Sat Feb 06 2010 Funda Wang <fwang@mandriva.org> 6.5.9.2-1mdv2010.1
+ Revision: 501277
- New version 6.5.9-2

* Tue Feb 02 2010 Funda Wang <fwang@mandriva.org> 6.5.9.1-1mdv2010.1
+ Revision: 499422
- new version 6.5.9-1

* Thu Jan 14 2010 Funda Wang <fwang@mandriva.org> 6.5.9.0-1mdv2010.1
+ Revision: 491130
- bump libmajor
- New version 6.5.9-0

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 6.5.8.10-2mdv2010.1
+ Revision: 488767
- rebuilt against libjpeg v8

* Fri Jan 01 2010 Funda Wang <fwang@mandriva.org> 6.5.8.10-1mdv2010.1
+ Revision: 484800
- new version 6.5.8-10

* Tue Dec 29 2009 Funda Wang <fwang@mandriva.org> 6.5.8.9-1mdv2010.1
+ Revision: 483212
- new version 6.5.8-9

* Fri Dec 25 2009 Funda Wang <fwang@mandriva.org> 6.5.8.8-1mdv2010.1
+ Revision: 482220
- new version 6.5.8-8

* Thu Dec 17 2009 Funda Wang <fwang@mandriva.org> 6.5.8.6-1mdv2010.1
+ Revision: 479766
- new version 6.5.8-6

* Sat Dec 12 2009 Funda Wang <fwang@mandriva.org> 6.5.8.5-1mdv2010.1
+ Revision: 477604
- new version 6.5.8-5

* Mon Dec 07 2009 Funda Wang <fwang@mandriva.org> 6.5.8.4-1mdv2010.1
+ Revision: 474334
- new version 6.5.8-4

* Sun Dec 06 2009 Funda Wang <fwang@mandriva.org> 6.5.8.3-1mdv2010.1
+ Revision: 474213
- new version 6.5.8.3

* Mon Nov 16 2009 Eugeni Dodonov <eugeni@mandriva.com> 6.5.7.7-1mdv2010.1
+ Revision: 466653
- Updated to 6.5.7.7.

* Thu Oct 22 2009 Eugeni Dodonov <eugeni@mandriva.com> 6.5.7.0-1mdv2010.0
+ Revision: 458947
- New version: 6.5.7.0

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 6.5.4.9-3mdv2010.0
+ Revision: 449104
- allow to bootstrap build by breaking buildloop imagemagick<>djvulibre
  (from Arnaud Patard)

* Sat Aug 15 2009 Oden Eriksson <oeriksson@mandriva.com> 6.5.4.9-2mdv2010.0
+ Revision: 416520
- rebuilt against libjpeg v7

* Sat Aug 08 2009 Funda Wang <fwang@mandriva.org> 6.5.4.9-1mdv2010.0
+ Revision: 411562
- new version 6.5.4-9

* Wed Aug 05 2009 Funda Wang <fwang@mandriva.org> 6.5.4.8-1mdv2010.0
+ Revision: 409926
- new version 6.5.4-8

* Sun Jul 26 2009 Funda Wang <fwang@mandriva.org> 6.5.4.5-1mdv2010.0
+ Revision: 400056
- New version 6.5.4-5

* Fri Jul 03 2009 Funda Wang <fwang@mandriva.org> 6.5.4.2-1mdv2010.0
+ Revision: 391882
- New version 6.5.4-2

* Sun Jun 28 2009 Funda Wang <fwang@mandriva.org> 6.5.4.0-1mdv2010.0
+ Revision: 390144
- New version 6.5.4-0

* Tue Jun 09 2009 Funda Wang <fwang@mandriva.org> 6.5.2.10-1mdv2010.0
+ Revision: 384212
- New version 6.5.2.10

* Thu May 28 2009 Eugeni Dodonov <eugeni@mandriva.com> 6.5.2.9-1mdv2010.0
+ Revision: 380390
- Updated to 6.5.2.9.

* Tue May 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 6.5.2.8-1mdv2010.0
+ Revision: 379915
- Updated to 6.5.2.8.

* Fri Mar 20 2009 Eugeni Dodonov <eugeni@mandriva.com> 6.5.0.2-1mdv2009.1
+ Revision: 359219
- Updated to latest upstream release.
  Updated to use correct docdir in man pages (#46104).
  Added correct BuildConflicts.

* Thu Mar 19 2009 Guillaume Rousse <guillomovitch@mandriva.org> 6.4.8.9-3mdv2009.1
+ Revision: 358191
- rebuild for latest graphviz

* Sat Jan 31 2009 Oden Eriksson <oeriksson@mandriva.com> 6.4.8.9-2mdv2009.1
+ Revision: 335843
- rebuilt against new jbigkit major

  + Götz Waschk <waschk@mandriva.org>
    - back to autoconf 2.5

* Wed Jan 28 2009 Götz Waschk <waschk@mandriva.org> 6.4.8.9-1mdv2009.1
+ Revision: 334964
- new version
- new major
- rediff patches 0,4,20
- patch format-string errors
- disable Werror, the perl binding does not work
- use the right configure macro

* Thu Nov 06 2008 Adam Williamson <awilliamson@mandriva.org> 6.4.5.4-1mdv2009.1
+ Revision: 300369
- rebuild for libxcb changes
- drop mgk.patch (merged upstream)
- new release 6.4.5-4

* Mon Sep 15 2008 Oden Eriksson <oeriksson@mandriva.com> 6.4.2.10-5mdv2009.0
+ Revision: 284863
- move suggests into the description (pixel)

* Fri Sep 12 2008 Oden Eriksson <oeriksson@mandriva.com> 6.4.2.10-4mdv2009.0
+ Revision: 284083
- turn delegate programs into suggests, fixes #40199

* Sun Sep 07 2008 Frederik Himpe <fhimpe@mandriva.org> 6.4.2.10-3mdv2009.0
+ Revision: 282371
- Rebuild for new djvulibre

* Tue Aug 19 2008 Adam Williamson <awilliamson@mandriva.org> 6.4.2.10-2mdv2009.0
+ Revision: 274053
- whoops, fix patch
- correct license
- add mgk.patch: fixes a small upstream error in configure

* Tue Aug 19 2008 Adam Williamson <awilliamson@mandriva.org> 6.4.2.10-1mdv2009.0
+ Revision: 274008
- rediff libpath.diff (part has been merged upstream)
- drop mpeg2.patch (superseded upstream)
- new release 6.4.2-10 (includes full replacement of mpeg2 tools with ffmpeg)

* Sat Aug 09 2008 Adam Williamson <awilliamson@mandriva.org> 6.4.2.6-1mdv2009.0
+ Revision: 270081
- add mpeg2.patch (from upstream svn, use ffmpeg in place of mpeg2decode)
- drop djvulibre_fix.diff (it wasn't actually fixing anything any more, just
  unnecessarily renaming options)
- new release 6.4.2-6

* Sun Jul 20 2008 Oden Eriksson <oeriksson@mandriva.com> 6.4.2.4-1mdv2009.0
+ Revision: 238905
- 6.4.2-4
- fix linkage against djvulibre (P1)
- fix ugly internal linkage (P21)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Fri May 16 2008 Oden Eriksson <oeriksson@mandriva.com> 6.4.1.1-1mdv2009.0
+ Revision: 208235
- disable the test suite for now
- second build attempt (duh!!!)
- 6.4.1-1
- nuke rpath (looked at fedora)

* Fri Apr 25 2008 Oden Eriksson <oeriksson@mandriva.com> 6.4.0.9-0mdv2009.0
+ Revision: 197411
- 6.4.0-9

* Tue Feb 19 2008 Oden Eriksson <oeriksson@mandriva.com> 6.3.8.9-1mdv2008.1
+ Revision: 172929
- 6.3.8-9

* Sat Feb 09 2008 Anssi Hannula <anssi@mandriva.org> 6.3.8.5-1mdv2008.1
+ Revision: 164617
- add %%minor_rev to %%version, it is not so minor (even libs were renamed
  with only it being raised)

* Sat Feb 09 2008 Anssi Hannula <anssi@mandriva.org> 6.3.8-2mdv2008.1
+ Revision: 164569
- drop library major check from prep (major is not supposed to be
  LIBRARY_CURRENT.LIBRARY_REVISION.LIBRARY_AGE, rather
  LIBRARY_CURRENT - LIBRARY_AGE; if upstream assumes something
  else, a proper fix is needed to avoid breakage in upgrade)
- rename library package to reflect correct major
- simplify file list
- own some unowned directories
- ensure major correctness

* Fri Feb 08 2008 Oden Eriksson <oeriksson@mandriva.com> 6.3.8-1mdv2008.1
+ Revision: 164215
- trying "make -j1" again...
- fix the multiarch stuff
- 6.3.8-5
- it cannot utilize %%make on x86_64, so just don't use that...
- bump release
- can't link against umem due to licensing issues
- added umem support
- 6.3.8-3
- dropped the libname patch, it's useless
- fixed deps
- added lqr support (experimental)

* Mon Jan 14 2008 Pixel <pixel@mandriva.com> 6.3.7-3mdv2008.1
+ Revision: 151250
- rebuild for perl-5.10.0

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu

* Tue Jan 08 2008 Oden Eriksson <oeriksson@mandriva.com> 6.3.7-2mdv2008.1
+ Revision: 146681
- really fix it
- --with-modules is borked, use --without-modules
- 6.3.7-9

* Fri Jan 04 2008 Oden Eriksson <oeriksson@mandriva.com> 6.3.7-1mdv2008.1
+ Revision: 144861
- 6.3.7-8
- major spec file rework
- fix deps
- repatched needed patches
- dropped obsolete patches
- fix #27044 (convert needs html2ps to convert HTML to PostScript)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Wed Sep 26 2007 Andreas Hasenack <andreas@mandriva.com> 6.3.2.9-10mdv2008.0
+ Revision: 93085
- fixed (lib)djvulibre-devel buildrequires
- fix build because of wrong font path (#34054)
- added security patch for CVE-2007-1667_1797 (#31911)

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Fri May 04 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.3.2.9-8mdv2008.0
+ Revision: 22582
- Revert bogus Obsoletes+major change from previous commit.

* Fri May 04 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 6.3.2.9-7mdv2008.0
+ Revision: 22554
- Rebuild with new jasper.
- Don't use major define on obsoletes because it can be modified making
  room for potential future errors (user changing major without noticing
  it has to change Obsoletes too).

* Sat Apr 21 2007 Anssi Hannula <anssi@mandriva.org> 6.3.2.9-6mdv2008.0
+ Revision: 16613
- rename to imagemagick
- move Imagemagick package tree to imagemagick


* Sun Mar 11 2007 Giuseppe Ghibò <ghibo@mandriva.com> 6.3.2.9-5mdv2007.1
+ Revision: 141362
- Added desktop subpackage and menu (fix bug #29331). "display" won't start without xterm (KDE bug?).

* Tue Mar 06 2007 Giuseppe Ghibò <ghibo@mandriva.com> 6.3.2.9-4mdv2007.1
+ Revision: 133476
- Fixed conflict in man pages between main and perl package (thanks to Pixel).

  + Anssi Hannula <anssi@mandriva.org>
    - remove unused options and fix description

* Sun Mar 04 2007 Anssi Hannula <anssi@mandriva.org> 6.3.2.9-3mdv2007.1
+ Revision: 132189
- plf: disable fpx build (broken)

* Thu Mar 01 2007 Giuseppe Ghibò <ghibo@mandriva.com> 6.3.2.9-2mdv2007.1
+ Revision: 130660
- Rebuilt.

* Sat Feb 24 2007 Giuseppe Ghibò <ghibo@mandriva.com> 6.3.2.9-1mdv2007.1
+ Revision: 125369
- Release: 6.3.2-9.

* Tue Feb 20 2007 Giuseppe Ghibò <ghibo@mandriva.com> 6.3.2.8-1mdv2007.1
+ Revision: 122953
- Release: 6.3.2-8.

* Fri Feb 16 2007 Götz Waschk <waschk@mandriva.org> 6.3.2.5-2mdv2007.1
+ Revision: 121898
- add djvulibre support
- fix description

* Fri Feb 16 2007 Götz Waschk <waschk@mandriva.org> 6.3.2.5-1mdv2007.1
+ Revision: 121701
- new version
- new major
- drop patches 1, 21
- rediff patch 17
- fix patch 7, it was producing invalid xml in a font configuration file

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Release: 6.2.9-8.
    - Removed Patch10 (no longer needed).
    - Rebuilt Patch19.
    - Merged Patch21 from Stew Benetict (security fix for CVE-2006-5456).
    - Import ImageMagick

* Thu Aug 31 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.9.2-1mdv2007.0
- Release: 6.2.9-2 (also fixes CVE-2006-3743,3744,4144).
- Bumped lib %%major to 10.4.0.

* Tue Aug 22 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.8.8-1mdv2007.0
- Release: 6.2.8-8.

* Thu Aug 03 2006 Götz Waschk <waschk@mandriva.org> 6.2.8.7-1mdv2007.0
- new version

* Wed Aug 02 2006 Frederic Crozat <fcrozat@mandriva.com> 6.2.8.4-2mdv2007.0
- Rebuild with latest dbus

* Wed Jul 19 2006 Götz Waschk <waschk@mandriva.org> 6.2.8.4-1mdv2007.0
- new release

* Tue Jul 04 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.8.3-1mdv2007.0
- Release: 6.2.8-3.

* Mon Jul 03 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.8.2-1mdv2007.0
- Release: 6.2.8-2.

* Fri Jun 30 2006 Götz Waschk <waschk@mandriva.org> 6.2.8.1-1mdv2007.0
- fix doc patch again
- update file list
- new version

* Mon Jun 19 2006 Stefan van der Eijk <stefan@eijk.nu.lurtspam> 6.2.8-1mdv2007.0
- rebuild for png

* Fri Jun 09 2006 Götz Waschk <waschk@mandriva.org> 6.2.8-1mdv2007.0
- new major
- new version

* Wed Apr 19 2006 Götz Waschk <waschk@mandriva.org> 6.2.7-1mdk
- move tests to %%check
- drop patch 12
- disable graphviz for now (needs 2.9 development snapshot)
- update deps
- fix doc location
- update patch 8,17
- new version

* Wed Apr 05 2006 Götz Waschk <waschk@mandriva.org> 6.2.6.8-1mdk
- new version

* Fri Mar 31 2006 Götz Waschk <waschk@mandriva.org> 6.2.6.7-1mdk
- New release 6.2.6.7

* Wed Mar 29 2006 Götz Waschk <waschk@mandriva.org> 6.2.6.4-4mdk
- fix devel exceptions for graphviz

* Fri Mar 24 2006 Götz Waschk <waschk@mandriva.org> 6.2.6.4-3mdk
- rebuild for graphviz

* Wed Mar 15 2006 Götz Waschk <waschk@mandriva.org> 6.2.6.4-2mdk
- spec fixes

* Mon Mar 13 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.6.4-1mdk
- 6.2.6-4.
- Rebuilt Patch8.

* Tue Feb 28 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.6.2-1mdk
- 6.2.6-2.

* Mon Jan 30 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.6.1-2mdk
- Bump major to 10.1.0.

* Mon Jan 30 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.6.1-1mdk
- 6.2.6-1.
- Rebuilt Patch10.
- Bump major to 10.0.0.

* Fri Jan 20 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.2.5.5-4mdk
- patch20: fix bug detected by montageImages test case on ppc

* Tue Jan 03 2006 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.5.5-3mdk
- fix major: should be derived from LIBRARY_CURRENT|REVISION|AGE.

* Sat Dec 31 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 6.2.5.5-2mdk
- fix major

* Fri Dec 23 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 6.2.5.5-1mdk
- 6.2.5-5
- regenerate P10
- convert to utf-8

* Tue Aug 30 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.4.3-1mdk
- Release: 6.2.4.3.

* Fri Aug 26 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.4.2-2mdk
- Removed type-windows.xml from type.xml (bug #10193).

* Thu Aug 25 2005 Oden Eriksson <oeriksson@mandriva.com> 6.2.4.2-1mdk
- 6.2.4-2
- nuke rpath
- new major

* Sun Aug 14 2005 GÃ¶tz Waschk <waschk@mandriva.org> 6.2.3.6-3mdk
- rebuild for new xorg

* Sat Aug 06 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.3.6-2mdk
- Rebuilt Patch8.

* Sat Aug 06 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.3.6-1mdk
- Release: 6.2.3-6.

* Fri Jul 22 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.3.4-1mdk
- Release: 6.2.3-4.

* Sun Jul 10 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.3.3-1mdk
- Release: 6.2.3-3.

* Sat Jun 25 2005 Giuseppe Ghibò <ghibo@mandriva.com> 6.2.3.2-1mdk
- Release: 6.2.3-2.
- Removed Patch20 (alphachannel), merged upstream.
- Rebuilt Patch10 (textfontsize).

* Thu Mar 31 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 6.2.0.3-8mdk
- fix #15097

* Sun Mar 20 2005 Christiaan Welvaart <cjw@daneel.dyndns.org> 6.2.0.3-7mdk
- add BuildRequires: libgd-devel

* Sat Mar 19 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.2.0.3-6mdk
- Rebuilt against latest jbigkit.

* Wed Mar 16 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 6.2.0.3-5mdk
- Rebuilt against fixed graphwiz libs

* Wed Mar 16 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.2.0.3-4mdk
- Backported patch from 6.2.0-8, for fixing wrong returned alpha channel when
  image don't have one.

* Thu Mar 10 2005 Pixel <pixel@mandrakesoft.com> 6.2.0.3-3mdk
- ensure "make -j 4" doesn't cause "perl Makefile.PL" to discard libMagick
  this fixes perl-Image-Magick which segfaulted because it was not linked with -lMagick.
- drop buggy patch14
  (the bugginess of patch14 comes from 5.5.7.15-3mdk)

* Wed Mar 02 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 6.2.0.3-2mdk
- fix the make test stuff with a twist

* Mon Feb 28 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.2.0.3-1mdk
- Release: 6.2.0-3.
- Disabled tests (problem with perl).

* Tue Feb 01 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 6.1.9.4-2mdk
- fix linking in the perl stuff (PLD)
- enable graphviz support
- run the tests (except x as it requires hands on)

* Mon Jan 31 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 6.1.9.4-1mdk
- fix deps and conditional %%multiarch.
- Release: 6.1.9-4.

* Sat Jan 22 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.9.2-1mdk
- Release: 6.1.9-2.

* Tue Jan 18 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.8.9-1mdk
- Release: 6.1.8-9.

* Sun Jan 16 2005 Guillaume Rousse <guillomovitch@mandrake.org> 6.1.8.7-3plf 
- fix perl module linkage
- use automake 1.8

* Sun Jan 16 2005 Luca Berra <bluca@vodka.it> 6.1.8.7-2mdk
- include parent directories in %%files

* Sat Jan 15 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.8.7-1mdk
- Release 6.8.1-7.

* Tue Jan 11 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.8.3-1mdk
- Release 6.8.1-3.

* Tue Jan 11 2005 Guillaume Rousse <guillomovitch@mandrake.org> 6.1.8.1-2mdk
- rebuild to have proper perl module linking (it still fails sometimes for unknwon reasons)
- perl package is perl-Image-Magick

* Sat Jan 08 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.8.1-1mdk
- Release 6.1.8-1.

* Thu Jan 06 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.7.6-1mdk
- Release 6.1.7-6.
- Rebuilt Patch7.
- Rebuilt Patch14.
- Added Patch18 (bug #10093).
- Jasper is in main, so use it.

* Tue Dec 28 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.7.5-1mdk
- Merged Charles A Edwards changes:
  - Release 6.1.7-5.
  - rm libltdl* files.

* Mon Dec 27 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.1.7.4-1mdk
- Removed Patch18 (merged upstream).
- Rebuilt Patch8.

* Sat Nov 27 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-8mdk
- security fix for CAN-2004-0981 (Vincent Danen).

* Wed Nov 24 2004 Götz Waschk <waschk@linux-mandrake.com> 6.0.4.4-7mdk
- enable jasper, it's in main

* Tue Nov 23 2004 Rafael Garcia-Suarez <rgarciasuarez@mandrakesoft.com> 6.0.4.4-6mdk
- Rebuild for new perl

* Sat Oct 09 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-5mdk
- Added Patch21, to fix security problems, CAN-2004-0827.

* Tue Sep 28 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-4mdk
- Added Patch20, to fix antialias problem during PS converting
  with ghostscript delegate (bug #11765).

* Sun Sep 12 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-3mdk
- Added Patch19, to fix grab button problem (bug #11207).

* Sun Sep 12 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-2mdk
- Added Patch18, to move windows font path later in type.mgk
  (fixes bug #10193).

* Tue Aug 17 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.4-1mdk
- Release: 6.0.4-4.

* Fri Aug 13 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.3-1mdk
- Release: 6.0.4-3.

* Fri Aug 06 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.2-1mdk
- Release: 6.0.4-2.
- Added -fPIC and --with-pic to have ImageMagick libraries working 
  with prelink (Thierry).

* Mon Aug 02 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 6.0.4.1-2mdk
- rebuilt to fix invalid vendor and distribution
- misc spec file fixes

* Thu Jul 29 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.4.1-1mdk
- Release: 6.0.4-1.

* Tue Jul 27 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.3.5-1mdk
- Release: 6.0.3-5.

* Tue Jul 20 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.3.3-1mdk
- Release: 6.0.3-3.
- Removed Patch15 (browser), merged upstream.

* Fri Jun 25 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.2.7-1mdk
- Release: 6.0.2-7.

* Sun Jun 13 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.2.6-1mdk
- Release: 6.0.2-6.

* Sat Jun 05 2004 Laurent Montel <lmontel@mandrakesoft.com> 6.0.1.4-2mdk
- Rebuild

* Tue Jun 01 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 6.0.1.4-1mdk
- Release: 6.0.1-4.
- Removed Patch11, merged upstream.
- Rebuilt Patch4, Patch7, Patch8, Patch14, Patch17.
- Force enable-lzw=no (probably up to 7 July 2004, when LZW patents
  will expire in Canada too).

* Tue Jun 01 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.5.7.20-1mdk
- Revision: 5.5.7-20.
- Updated Patch12.

* Thu Apr 08 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.5.7.17-2mdk
- Merged Götz patches from 5.5.7.15-6mdk.

* Sun Apr 04 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 5.5.7.17-1mdk
- Revision: 5.5.7-17.
- Removed Patch16 for freetype2 (no longer needed).

